% Auto-generated chapter 50 for muslim
% Hadiths in this chapter: 63

\hadithdefcmd{muslim}{6952}{حَدَّثَنِي سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا حَفْصُ بْنُ مَيْسَرَةَ، حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ أَبِي، صَالِحٍ عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ أَنَا عِنْدَ ظَنِّ عَبْدِي بِي وَأَنَا مَعَهُ حَيْثُ يَذْكُرُنِي وَاللَّهِ لَلَّهُ أَفْرَحُ بِتَوْبَةِ عَبْدِهِ مِنْ أَحَدِكُمْ يَجِدُ ضَالَّتَهُ بِالْفَلاَةِ وَمَنْ تَقَرَّبَ إِلَىَّ شِبْرًا تَقَرَّبْتُ إِلَيْهِ ذِرَاعًا وَمَنْ تَقَرَّبَ إِلَىَّ ذِرَاعًا تَقَرَّبْتُ إِلَيْهِ بَاعًا وَإِذَا أَقْبَلَ إِلَىَّ يَمْشِي أَقْبَلْتُ إِلَيْهِ أُهَرْوِلُ ‏"‏ ‏.‏\hadithno{6952}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah, the Exalted and Glorious, said: I live in the thought of My servant and I am with him as he remembers Me. (The Holy Prophet) further said: By Allah, Allah is more pleased wth the repentance of His servant than what one of you would do on finding the lost camel in the waterless desert. When he draws near Me by the span of his hand. I draw near him by the length of a cubit and when he draws near Me by the length of a cubit. I draw near him by the length of a fathom and when he draws near Me walking I draw close to him hurriedly}}
\hadithdefcmd{muslim}{6953}{حَدَّثَنِي عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ بْنِ قَعْنَبٍ الْقَعْنَبِيُّ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي ابْنَ عَبْدِ الرَّحْمَنِ الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَلَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ أَحَدِكُمْ مِنْ أَحَدِكُمْ بِضَالَّتِهِ إِذَا وَجَدَهَا ‏"‏ ‏.‏\hadithno{6953}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah is more pleased with the repentance of His servant when he turns penitently towards Him than one of you would be on finding the lost camel}}
\hadithdefcmd{muslim}{6954}{وَحَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، حَدَّثَنَا مَعْمَرٌ، عَنْ هَمَّامِ بْنِ مُنَبِّهٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏\hadithno{6954}\hadithtrans{This hadith has been narrated on the authority of Abu Huraira through another chain of transmitters}}
\hadithdefcmd{muslim}{6955}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، - وَاللَّفْظُ لِعُثْمَانَ - قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ عُمَارَةَ بْنِ عُمَيْرٍ، عَنِ الْحَارِثِ بْنِ، سُوَيْدٍ قَالَ دَخَلْتُ عَلَى عَبْدِ اللَّهِ أَعُودُهُ وَهُوَ مَرِيضٌ فَحَدَّثَنَا بِحَدِيثَيْنِ حَدِيثًا عَنْ نَفْسِهِ وَحَدِيثًا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَلَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ عَبْدِهِ الْمُؤْمِنِ مِنْ رَجُلٍ فِي أَرْضٍ دَوِيَّةٍ مَهْلَكَةٍ مَعَهُ رَاحِلَتُهُ عَلَيْهَا طَعَامُهُ وَشَرَابُهُ فَنَامَ فَاسْتَيْقَظَ وَقَدْ ذَهَبَتْ فَطَلَبَهَا حَتَّى أَدْرَكَهُ الْعَطَشُ ثُمَّ قَالَ أَرْجِعُ إِلَى مَكَانِي الَّذِي كُنْتُ فِيهِ فَأَنَامُ حَتَّى أَمُوتَ ‏.‏ فَوَضَعَ رَأْسَهُ عَلَى سَاعِدِهِ لِيَمُوتَ فَاسْتَيْقَظَ وَعِنْدَهُ رَاحِلَتُهُ وَعَلَيْهَا زَادُهُ وَطَعَامُهُ وَشَرَابُهُ فَاللَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ الْعَبْدِ الْمُؤْمِنِ مِنْ هَذَا بِرَاحِلَتِهِ وَزَادِهِ ‏"‏ ‏.‏\hadithno{6955}\hadithtrans{Harith b. Suwaid said:I went to see 'Abdullah to inquire about his health as he was sick and he narrated to us a hadith of Allahs Messenger (ﷺ). He heard Allah's Messenger (ﷺ) as saying: Allah is more pleased with the repentance of His believing servant than a person who loses his riding beast carrying food and drink. He sleeps (being disappointed of its recovery) and then gets up and goes in search for that, until he is stricken with thirst. then comes back to the place where he had been before and goes to sleep completely exhausted placing his head upon his hands waiting for death. And when he gets up, lot there is before him his riding beast and his provisions of food and drink. Allah is more pleased with the repentance of His servant than the recovery of this riding beast along with the provisions (of food and drink)}}
\hadithdefcmd{muslim}{6956}{وَحَدَّثَنَاهُ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَحْيَى بْنُ آدَمَ، عَنْ قُطْبَةَ بْنِ عَبْدِ الْعَزِيزِ، عَنِ الأَعْمَشِ، بِهَذَا الإِسْنَادِ وَقَالَ ‏ "‏ مِنْ رَجُلٍ بِدَاوِيَّةٍ مِنَ الأَرْضِ ‏"‏ ‏.‏\hadithno{6956}\hadithtrans{This hadith has been narrated on the authority of A'mash through another chain of transmitters}}
\hadithdefcmd{muslim}{6957}{وَحَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا عُمَارَةُ، بْنُ عُمَيْرٍ قَالَ سَمِعْتُ الْحَارِثَ بْنَ سُوَيْدٍ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ، حَدِيثَيْنِ أَحَدُهُمَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَالآخَرُ عَنْ نَفْسِهِ فَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَلَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ عَبْدِهِ الْمُؤْمِنِ ‏"‏ ‏.‏ بِمِثْلِ حَدِيثِ جَرِيرٍ ‏.‏\hadithno{6957}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:Allah is more pleased with the repentance of a believing man. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{6958}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو يُونُسَ، عَنْ سِمَاكٍ، قَالَ خَطَبَ النُّعْمَانُ بْنُ بَشِيرٍ فَقَالَ ‏ "‏ لَلَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ عَبْدِهِ مِنْ رَجُلٍ حَمَلَ زَادَهُ وَمَزَادَهُ عَلَى بَعِيرٍ ثُمَّ سَارَ حَتَّى كَانَ بِفَلاَةٍ مِنَ الأَرْضِ فَأَدْرَكَتْهُ الْقَائِلَةُ فَنَزَلَ فَقَالَ تَحْتَ شَجَرَةٍ فَغَلَبَتْهُ عَيْنُهُ وَانْسَلَّ بَعِيرُهُ فَاسْتَيْقَظَ فَسَعَى شَرَفًا فَلَمْ يَرَ شَيْئًا ثُمَّ سَعَى شَرَفًا ثَانِيًا فَلَمْ يَرَ شَيْئًا ثُمَّ سَعَى شَرَفًا ثَالِثًا فَلَمْ يَرَ شَيْئًا فَأَقْبَلَ حَتَّى أَتَى مَكَانَهُ الَّذِي قَالَ فِيهِ فَبَيْنَمَا هُوَ قَاعِدٌ إِذْ جَاءَهُ بَعِيرُهُ يَمْشِي حَتَّى وَضَعَ خِطَامَهُ فِي يَدِهِ فَلَلَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ الْعَبْدِ مِنْ هَذَا حِينَ وَجَدَ بَعِيرَهُ عَلَى حَالِهِ ‏"‏ ‏.‏ قَالَ سِمَاكٌ فَزَعَمَ الشَّعْبِيُّ أَنَّ النُّعْمَانَ رَفَعَ هَذَا الْحَدِيثَ إِلَى النَّبِيِّ صلى الله عليه وسلم وَأَمَّا أَنَا فَلَمْ أَسْمَعْهُ ‏.‏\hadithno{6958}\hadithtrans{Nu'man b. Bashir reported:Allah is more pleased with the repentance of a believing servant than of a person who set out on a journey with a provision of food and drink on the back of his camel. He went on until he came to a waterless desert and he felt like sleeping. So he got down under the shade of a tree and was overcome by sleep and his camel ran away. As he got up he tried to see (the camel) standing upon a mound. but did not find it. He then got upon the other mound, but could not see anything. He then climbed upon the third mound but did not see anything until he came back to the place where he had been previously. And as he was sitting (in utter disappointment) there came to him the camel, till that (camel) placed its nosestring in his hand. Allah is more pleased with the repentance of His servant than the person who found (his lost camel) in this very state. Simak reported that Sha'bi was of the opinion that Nu'min traced it to Allah's Apostle (ﷺ). Simak, however, did not hear that himself}}
\hadithdefcmd{muslim}{6959}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَجَعْفَرُ بْنُ حُمَيْدٍ، قَالَ جَعْفَرٌ حَدَّثَنَا وَقَالَ، يَحْيَى أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ إِيَادِ بْنِ لَقِيطٍ، عَنْ إِيَادٍ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ كَيْفَ تَقُولُونَ بِفَرَحِ رَجُلٍ انْفَلَتَتْ مِنْهُ رَاحِلَتُهُ تَجُرُّ زِمَامَهَا بِأَرْضٍ قَفْرٍ لَيْسَ بِهَا طَعَامٌ وَلاَ شَرَابٌ وَعَلَيْهَا لَهُ طَعَامٌ وَشَرَابٌ فَطَلَبَهَا حَتَّى شَقَّ عَلَيْهِ ثُمَّ مَرَّتْ بِجِذْلِ شَجَرَةٍ فَتَعَلَّقَ زِمَامُهَا فَوَجَدَهَا مُتَعَلِّقَةً بِهِ ‏"‏ ‏.‏ قُلْنَا شَدِيدًا يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَمَا وَاللَّهِ لَلَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ عَبْدِهِ مِنَ الرَّجُلِ بِرَاحِلَتِهِ ‏"‏ ‏.‏ قَالَ جَعْفَرٌ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ إِيَادٍ عَنْ أَبِيهِ ‏.‏\hadithno{6959}\hadithtrans{Al-Bara' b. 'Azib reported Allah's Messenger (ﷺ) as saying that Allah's Messenger (ﷺ) said:What is your opinion about the delight of a person whose camel loaded with the provisions of food and drink is lost and that moves about with its nosestring trailing upon the waterless desert in which there is neither food nor drink, and lie wanders about in search of that until he is completely exhausted and then accidentally it happens to pass by the trunk of a tree and its nosestring gets entangled in that and he finds it entangled therein? He (in response to the question of the Holy Prophet) said: Allah's Messenger, he would feel highly delighted. Thereupon Allah's Messenger (ﷺ) said. By Allah, Allah is more delighted at the repentance of His servant than that person (as he finds his lost) camel}}
\hadithdefcmd{muslim}{6960}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَزُهَيْرُ بْنُ حَرْبٍ، قَالاَ حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، - وَهُوَ عَمُّهُ - قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَلَّهُ أَشَدُّ فَرَحًا بِتَوْبَةِ عَبْدِهِ حِينَ يَتُوبُ إِلَيْهِ مِنْ أَحَدِكُمْ كَانَ عَلَى رَاحِلَتِهِ بِأَرْضِ فَلاَةٍ فَانْفَلَتَتْ مِنْهُ وَعَلَيْهَا طَعَامُهُ وَشَرَابُهُ فَأَيِسَ مِنْهَا فَأَتَى شَجَرَةً فَاضْطَجَعَ فِي ظِلِّهَا قَدْ أَيِسَ مِنْ رَاحِلَتِهِ فَبَيْنَا هُوَ كَذَلِكَ إِذَا هُوَ بِهَا قَائِمَةً عِنْدَهُ فَأَخَذَ بِخِطَامِهَا ثُمَّ قَالَ مِنْ شِدَّةِ الْفَرَحِ اللَّهُمَّ أَنْتَ عَبْدِي وَأَنَا رَبُّكَ ‏.‏ أَخْطَأَ مِنْ شِدَّةِ الْفَرَحِ ‏"‏ ‏.‏\hadithno{6960}\hadithtrans{Anas b. Malik reported that Allah's Messenger (ﷺ) said:Allah is more pleased with the repentance of a servant as he turns towards Him for repentance than this that one amongst you is upon the camel in a waterless desert and there is upon (that camel) his provision of food and drink also and it is lost by him, and he having lost all hope (to get tbat) lies down in the shadow and is disappointed about his camel and there he finds that camel standing before him. He takes hold of his nosestring and then out of boundless joy says: 0 Lord, Thou art my servant and I am Thine Lord. He commits this mistake out of extreme delight}}
\hadithdefcmd{muslim}{6963}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا لَيْثٌ، عَنْ مُحَمَّدِ بْنِ قَيْسٍ، - قَاصِّ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ - عَنْ أَبِي صِرْمَةَ، عَنْ أَبِي أَيُّوبَ، أَنَّهُ قَالَ حِينَ حَضَرَتْهُ الْوَفَاةُ كُنْتُ كَتَمْتُ عَنْكُمْ شَيْئًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَوْلاَ أَنَّكُمْ تُذْنِبُونَ لَخَلَقَ اللَّهُ خَلْقًا يُذْنِبُونَ يَغْفِرُ لَهُمْ ‏"‏ ‏.‏\hadithno{6963}\hadithtrans{Abu Sirma reported that when the time of the death of Abu Ayyub Ansari drew near, he said:I used to conceal from you a thing which I heard from Allah's Messenger (ﷺ) and I heard Allah's Messenger (ﷺ) as saying: Had you not committed sins, Allah would have brought into existence a creation that would have committed sin (and Allah) would have forgiven them}}
\hadithdefcmd{muslim}{6964}{حَدَّثَنَا هَارُونُ بْنُ سَعِيدٍ الأَيْلِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، حَدَّثَنِي عِيَاضٌ، - وَهُوَ ابْنُ عَبْدِ اللَّهِ الْفِهْرِيُّ - حَدَّثَنِي إِبْرَاهِيمُ بْنُ عُبَيْدِ بْنِ رِفَاعَةَ، عَنْ مُحَمَّدِ بْنِ كَعْبٍ الْقُرَظِيِّ، عَنْ أَبِي صِرْمَةَ، عَنْ أَبِي أَيُّوبَ الأَنْصَارِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لَوْ أَنَّكُمْ لَمْ تَكُنْ لَكُمْ ذُنُوبٌ يَغْفِرُهَا اللَّهُ لَكُمْ لَجَاءَ اللَّهُ بِقَوْمٍ لَهُمْ ذُنُوبٌ يَغْفِرُهَا لَهُمْ ‏"‏ ‏.‏\hadithno{6964}\hadithtrans{Abu Ayyub Ansari reported that Allah's Messenger (ﷺ) said:If you were not to commit sins, Allah would have swept you out of existence and would have replaced you by another people who have committed sin, and then asked forgiveness from Allah, and He would have granted them pardon}}
\hadithdefcmd{muslim}{6965}{حَدَّثَنِي مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ جَعْفَرٍ الْجَزَرِيِّ، عَنْ يَزِيدَ بْنِ الأَصَمِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْ لَمْ تُذْنِبُوا لَذَهَبَ اللَّهُ بِكُمْ وَلَجَاءَ بِقَوْمٍ يُذْنِبُونَ فَيَسْتَغْفِرُونَ اللَّهَ فَيَغْفِرُ لَهُمْ ‏"‏ ‏.‏\hadithno{6965}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) having said:By Him in Whose Hand is my life, if you were not to commit sin, Allah would sweep you out of existence and He would replace (you by) those people who would commit sin and seek forgiveness from Allah, and He would have pardoned them}}
\hadithdefcmd{muslim}{6966}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى التَّمِيمِيُّ، وَقَطَنُ بْنُ نُسَيْرٍ، - وَاللَّفْظُ لِيَحْيَى - أَخْبَرَنَا جَعْفَرُ، بْنُ سُلَيْمَانَ عَنْ سَعِيدِ بْنِ إِيَاسٍ الْجُرَيْرِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ حَنْظَلَةَ الأُسَيِّدِيِّ، قَالَ - وَكَانَ مِنْ كُتَّابِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ - لَقِيَنِي أَبُو بَكْرٍ فَقَالَ كَيْفَ أَنْتَ يَا حَنْظَلَةُ قَالَ قُلْتُ نَافَقَ حَنْظَلَةُ قَالَ سُبْحَانَ اللَّهِ مَا تَقُولُ قَالَ قُلْتُ نَكُونُ عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم يُذَكِّرُنَا بِالنَّارِ وَالْجَنَّةِ حَتَّى كَأَنَّا رَأْىَ عَيْنٍ فَإِذَا خَرَجْنَا مِنْ عِنْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم عَافَسْنَا الأَزْوَاجَ وَالأَوْلاَدَ وَالضَّيْعَاتِ فَنَسِينَا كَثِيرًا قَالَ أَبُو بَكْرٍ فَوَاللَّهِ إِنَّا لَنَلْقَى مِثْلَ هَذَا ‏.‏ فَانْطَلَقْتُ أَنَا وَأَبُو بَكْرٍ حَتَّى دَخَلْنَا عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم قُلْتُ نَافَقَ حَنْظَلَةُ يَا رَسُولَ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَمَا ذَاكَ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ نَكُونُ عِنْدَكَ تُذَكِّرُنَا بِالنَّارِ وَالْجَنَّةِ حَتَّى كَأَنَّا رَأْىَ عَيْنٍ فَإِذَا خَرَجْنَا مِنْ عِنْدِكَ عَافَسْنَا الأَزْوَاجَ وَالأَوْلاَدَ وَالضَّيْعَاتِ نَسِينَا كَثِيرًا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ إِنْ لَوْ تَدُومُونَ عَلَى مَا تَكُونُونَ عِنْدِي وَفِي الذِّكْرِ لَصَافَحَتْكُمُ الْمَلاَئِكَةُ عَلَى فُرُشِكُمْ وَفِي طُرُقِكُمْ وَلَكِنْ يَا حَنْظَلَةُ سَاعَةً وَسَاعَةً ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{6966}\hadithtrans{Hanzala Usayyidi, who was amongst the scribes of Allah's Messenger (ﷺ). reported:I met Abu Bakr. He said: Who are you? He (Hanzala) said: Hanzala has turned to be a hypocrite. He (Abu Bakr) said: Hallowed be Allah, what are you saying? Thereupon he said: I say that when we are in the company of Allah's Messenger (ﷺ) we ponder over Hell-Fire and Paradise as if we are seeing them with our very eyes and when we are away from Allah's Messenger (ﷺ) we attend to our wives, our children, our business; most of these things (pertaining to After-life) slip out of our minds. Abu Bakr said: By Allah, I also experience the same. So I and Abu Bakr went to Allah's Messenger (ﷺ) and said to him: Allah's Messenger, Hanzala has turned to be a hypocrite. Thereupon Allah's Messenger (ﷺ) said: What has happened to you? I said: Allah's Messenger, when we are in your company, we are reminded of Hell-Fire and Paradise as if we are seeing them with our own eyes, but whenever we go away from you and attend to our wives, children and business, much of these things go out of our minds. Thereupon Allah's Messenger (ﷺ) said: By Him in Whose Hand is my life, if your state of mind remains the same as it is in my presence and you are always busy in remembrance (of Allah), the Angels will shake hands with you in your beds and in your paths but, Hanzala, time should be devoted (to the worldly affairs) and time (should be devoted to prayer and meditation). He (the Holy Prophet) said this thrice}}
\hadithdefcmd{muslim}{6967}{حَدَّثَنِي إِسْحَاقُ بْنُ مَنْصُورٍ، أَخْبَرَنَا عَبْدُ الصَّمَدِ، سَمِعْتُ أَبِي يُحَدِّثُ، حَدَّثَنَا سَعِيدٌ، الْجُرَيْرِيُّ عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ حَنْظَلَةَ، قَالَ كُنَّا عِنْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَوَعَظَنَا فَذَكَّرَ النَّارَ - قَالَ - ثُمَّ جِئْتُ إِلَى الْبَيْتِ فَضَاحَكْتُ الصِّبْيَانَ وَلاَعَبْتُ الْمَرْأَةَ - قَالَ - فَخَرَجْتُ فَلَقِيتُ أَبَا بَكْرٍ فَذَكَرْتُ ذَلِكَ لَهُ فَقَالَ وَأَنَا قَدْ فَعَلْتُ مِثْلَ مَا تَذْكُرُ ‏.‏ فَلَقِينَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ نَافَقَ حَنْظَلَةُ فَقَالَ ‏"‏ مَهْ ‏"‏ ‏.‏ فَحَدَّثْتُهُ بِالْحَدِيثِ فَقَالَ أَبُو بَكْرٍ وَأَنَا قَدْ فَعَلْتُ مِثْلَ مَا فَعَلَ فَقَالَ ‏"‏ يَا حَنْظَلَةُ سَاعَةً وَسَاعَةً وَلَوْ كَانَتْ تَكُونُ قُلُوبُكُمْ كَمَا تَكُونُ عِنْدَ الذِّكْرِ لَصَافَحَتْكُمُ الْمَلاَئِكَةُ حَتَّى تُسَلِّمَ عَلَيْكُمْ فِي الطُّرُقِ ‏"‏ ‏.‏\hadithno{6967}\hadithtrans{Hanzala reported:We were in the company of Allah's Messenger (ﷺ) and he delivered to us a sermon and made a mention of Hell-Fire. Then I came to my house and began to laugh with my children and sport with my wife. (Hanzala) further reported: I went out and met Abu Bakr and made a mention of that to him. Thereupon he said: I have done the same as you have mentioned. So we went to see Allah's Messenger (ﷺ) and said to him: Allah's Messenger, Hanzala has turned to he a hypocrite. And he (the Holy Prophet) said Show respite. And then I narrated to him the story, and Abu Bakr said: I have done the same as he has done. Thereupon he (the Holy Prophet) said: Hanzala, there is a time for worldly affairs and a time for (worship and devotion), and if your state of mind is always the same as it is at the time of remembrance of Allah, the Angels would shake hands with you and would greet you on the path by saying: As-Salamu-Alaikum}}
\hadithdefcmd{muslim}{6968}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا سُفْيَانُ، عَنْ سَعِيدٍ الْجُرَيْرِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنْ حَنْظَلَةَ التَّمِيمِيِّ الأُسَيِّدِيِّ الْكَاتِبِ، قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَذَكَّرَنَا الْجَنَّةَ وَالنَّارَ ‏.‏ فَذَكَرَ نَحْوَ حَدِيثِهِمَا ‏.‏\hadithno{6968}\hadithtrans{Hanzala Taimi Ufayyidi, the scribe of Allah's Messenger (ﷺ), reported:We were in the presence of Allah's Messenger (ﷺ) and he brought to our minds the problems pertaining to Paradise and Hell-Fire. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{6969}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا الْمُغِيرَةُ، - يَعْنِي الْحِزَامِيَّ - عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَمَّا خَلَقَ اللَّهُ الْخَلْقَ كَتَبَ فِي كِتَابِهِ فَهُوَ عِنْدَهُ فَوْقَ الْعَرْشِ إِنَّ رَحْمَتِي تَغْلِبُ غَضَبِي ‏"‏ ‏.‏\hadithno{6969}\hadithtrans{Abu Huraira reported that Allah's Messenger (ﷺ) said:When Allah created the creation as He was upon the Throne, He put down in His Book: Verily, My mercy predominates My wrath}}
\hadithdefcmd{muslim}{6970}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ قَالَ اللَّهُ عَزَّ وَجَلَّ سَبَقَتْ رَحْمَتِي غَضَبِي ‏"‏ ‏.‏\hadithno{6970}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah, the Exalted and Glorious, said: My mercy excels My wrath}}
\hadithdefcmd{muslim}{6971}{حَدَّثَنَا عَلِيُّ بْنُ خَشْرَمٍ، أَخْبَرَنَا أَبُو ضَمْرَةَ، عَنِ الْحَارِثِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَطَاءِ، بْنِ مِينَاءَ عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَمَّا قَضَى اللَّهُ الْخَلْقَ كَتَبَ فِي كِتَابِهِ عَلَى نَفْسِهِ فَهُوَ مَوْضُوعٌ عِنْدَهُ إِنَّ رَحْمَتِي تَغْلِبُ غَضَبِي ‏"‏ ‏.‏\hadithno{6971}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:When Allah created the creation, He ordained for Himself and this document is with Him: Verily, My mercy predominates Mv wrath}}
\hadithdefcmd{muslim}{6972}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى التُّجِيبِيُّ، أَخْبَرَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَنَّ سَعِيدَ بْنَ الْمُسَيَّبِ، أَخْبَرَهُ أَنَّ أَبَا هُرَيْرَةَ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ جَعَلَ اللَّهُ الرَّحْمَةَ مِائَةَ جُزْءٍ فَأَمْسَكَ عِنْدَهُ تِسْعَةً وَتِسْعِينَ وَأَنْزَلَ فِي الأَرْضِ جُزْءًا وَاحِدًا فَمِنْ ذَلِكَ الْجُزْءِ تَتَرَاحَمُ الْخَلاَئِقُ حَتَّى تَرْفَعَ الدَّابَّةُ حَافِرَهَا عَنْ وَلَدِهَا خَشْيَةَ أَنْ تُصِيبَهُ ‏"‏ ‏.‏\hadithno{6972}\hadithtrans{Abu Huraira reported:I heard Allah's Messenger (ﷺ) as saying: Allah created mercy in one hundred parts and He retained with Him ninety-nine parts, and He has sent down upon the earth one part, and it is because of this one part that there is mutual love among the creation so much so that the animal lifts up its hoof from its young one, fearing that it might harm it}}
\hadithdefcmd{muslim}{6973}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ قَالُوا حَدَّثَنَا إِسْمَاعِيلُ، - يَعْنُونَ ابْنَ جَعْفَرٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَلَقَ اللَّهُ مِائَةَ رَحْمَةٍ فَوَضَعَ وَاحِدَةً بَيْنَ خَلْقِهِ وَخَبَأَ عِنْدَهُ مِائَةً إِلاَّ وَاحِدَةً ‏"‏ ‏.‏\hadithno{6973}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah created one hundred (parts of mercy) and He distributed one amongst His creation and kept this one hundred excepting one with Himself (for the Day of Resurrection)}}
\hadithdefcmd{muslim}{6974}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبِي، حَدَّثَنَا عَبْدُ الْمَلِكِ، عَنْ عَطَاءٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ لِلَّهِ مِائَةَ رَحْمَةٍ أَنْزَلَ مِنْهَا رَحْمَةً وَاحِدَةً بَيْنَ الْجِنِّ وَالإِنْسِ وَالْبَهَائِمِ وَالْهَوَامِّ فَبِهَا يَتَعَاطَفُونَ وَبِهَا يَتَرَاحَمُونَ وَبِهَا تَعْطِفُ الْوَحْشُ عَلَى وَلَدِهَا وَأَخَّرَ اللَّهُ تِسْعًا وَتِسْعِينَ رَحْمَةً يَرْحَمُ بِهَا عِبَادَهُ يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6974}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:There are one hundred (parts of) mercy for Allah and He has sent down out of these one part of mercy upon the jinn and human beings and animals and the insects, and it is because of this (one part) that they love one another, show kindness to one another and even the beast treats its young one with affection, and Allah has reserved ninety nine parts of mercy with which He would treat His servants on the Day of Resurrection}}
\hadithdefcmd{muslim}{6975}{حَدَّثَنِي الْحَكَمُ بْنُ مُوسَى، حَدَّثَنَا مُعَاذُ بْنُ مُعَاذٍ، حَدَّثَنَا سُلَيْمَانُ التَّيْمِيُّ، حَدَّثَنَا أَبُو عُثْمَانَ النَّهْدِيُّ عَنْ سَلْمَانَ الْفَارِسِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ لِلَّهِ مِائَةَ رَحْمَةٍ فَمِنْهَا رَحْمَةٌ بِهَا يَتَرَاحَمُ الْخَلْقُ بَيْنَهُمْ وَتِسْعَةٌ وَتِسْعُونَ لِيَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{6975}\hadithtrans{Salman Farisi reported Allah's Messenger (ﷺ) as saying:Verily, there are one hundred (parts of) mercy for Allah, and it is one part of this mercy by virtue of which there is mutual love between the people and ninety-nine reserved for the Day of Resurrection}}
\hadithdefcmd{muslim}{6976}{وَحَدَّثَنَاهُ مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6976}\hadithtrans{This hadith has been transmitted on the authority of Mu'tamir, reported on the authority of his father}}
\hadithdefcmd{muslim}{6977}{حَدَّثَنَا ابْنُ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنْ أَبِي عُثْمَانَ، عَنْ سَلْمَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ خَلَقَ يَوْمَ خَلَقَ السَّمَوَاتِ وَالأَرْضَ مِائَةَ رَحْمَةٍ كُلُّ رَحْمَةٍ طِبَاقَ مَا بَيْنَ السَّمَاءِ وَالأَرْضِ فَجَعَلَ مِنْهَا فِي الأَرْضِ رَحْمَةً فَبِهَا تَعْطِفُ الْوَالِدَةُ عَلَى وَلَدِهَا وَالْوَحْشُ وَالطَّيْرُ بَعْضُهَا عَلَى بَعْضٍ فَإِذَا كَانَ يَوْمُ الْقِيَامَةِ أَكْمَلَهَا بِهَذِهِ الرَّحْمَةِ ‏"‏ ‏.‏\hadithno{6977}\hadithtrans{Salman reported that Allah's Messenger (ﷺ) said:Verily, Allah created, on the same very day when He created the heavens and the earth, one hundred parts of mercy. Every part of mercy is coextensive with the space between the heavens. and the earth and He out of this mercy endowed one part to the earth and it is because of this that the mother shows affection to her child and even the beasts and birds show kindness to one another and when there would be the Day of Resurrection, Allah would make full (use of Mercy)}}
\hadithdefcmd{muslim}{6978}{حَدَّثَنِي الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، وَمُحَمَّدُ بْنُ سَهْلٍ التَّمِيمِيُّ، - وَاللَّفْظُ لِحَسَنٍ - حَدَّثَنَا ابْنُ أَبِي مَرْيَمَ، حَدَّثَنَا أَبُو غَسَّانَ، حَدَّثَنِي زَيْدُ بْنُ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، أَنَّهُ قَالَ قَدِمَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِسَبْىٍ فَإِذَا امْرَأَةٌ مِنَ السَّبْىِ تَبْتَغِي إِذَا وَجَدَتْ صَبِيًّا فِي السَّبْىِ أَخَذَتْهُ فَأَلْصَقَتْهُ بِبَطْنِهَا وَأَرْضَعَتْهُ فَقَالَ لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَرَوْنَ هَذِهِ الْمَرْأَةَ طَارِحَةً وَلَدَهَا فِي النَّارِ ‏"‏ ‏.‏ قُلْنَا لاَ وَاللَّهِ وَهِيَ تَقْدِرُ عَلَى أَنْ لاَ تَطْرَحَهُ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لَلَّهُ أَرْحَمُ بِعِبَادِهِ مِنْ هَذِهِ بِوَلَدِهَا ‏"‏ ‏.‏\hadithno{6978}\hadithtrans{Umar b. Khattab reported that there were brought some prisoners to Allah's Messenger (ﷺ) amongst whom there was also a woman, who was searching (for someone) and when she found a child amongst the prisoners, she took hold of it, pressed it against her chest and provided it suck. Thereupon Allah's Messenger (ﷺ) said:Do you think this woman would ever afford to throw her child in the Fire? We said: By Allah, so far as it lies in her power, she would never throw the child in Fire. ' Thereupon Allah's Messenger (ﷺ) said: Allah is more kind to His servants than this woman is to her child}}
\hadithdefcmd{muslim}{6979}{حَدَّثَنَا يَحْيَى بْنُ أَيُّوبَ، وَقُتَيْبَةُ، وَابْنُ، حُجْرٍ جَمِيعًا عَنْ إِسْمَاعِيلَ بْنِ جَعْفَرٍ، قَالَ ابْنُ أَيُّوبَ حَدَّثَنَا إِسْمَاعِيلُ، أَخْبَرَنِي الْعَلاَءُ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَوْ يَعْلَمُ الْمُؤْمِنُ مَا عِنْدَ اللَّهِ مِنَ الْعُقُوبَةِ مَا طَمِعَ بِجَنَّتِهِ أَحَدٌ وَلَوْ يَعْلَمُ الْكَافِرُ مَا عِنْدَ اللَّهِ مِنَ الرَّحْمَةِ مَا قَنِطَ مِنْ جَنَّتِهِ أَحَدٌ ‏"‏ ‏.‏\hadithno{6979}\hadithtrans{Ala' reported on the authority of his father who reported on the authority of Abu Huraira that Allah's Messenger (ﷺ) said:If a believer were to know the punishment (in Hell) none would have the audacity to aspire for Paradise (but he would earnestly desire to be rescued from Hell), and if a non-believer were to know what is there with Allah as a mercy. none would have been disappointed in regard to Paradise}}
\hadithdefcmd{muslim}{6980}{حَدَّثَنِي مُحَمَّدُ بْنُ مَرْزُوقِ ابْنِ بِنْتِ مَهْدِيِّ بْنِ مَيْمُونٍ، حَدَّثَنَا رَوْحٌ، حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ قَالَ رَجُلٌ لَمْ يَعْمَلْ حَسَنَةً قَطُّ لأَهْلِهِ إِذَا مَاتَ فَحَرِّقُوهُ ثُمَّ اذْرُوا نِصْفَهُ فِي الْبَرِّ وَنِصْفَهُ فِي الْبَحْرِ فَوَاللَّهِ لَئِنْ قَدَرَ اللَّهُ عَلَيْهِ لَيُعَذِّبَنَّهُ عَذَابًا لاَ يُعَذِّبُهُ أَحَدًا مِنَ الْعَالَمِينَ فَلَمَّا مَاتَ الرَّجُلُ فَعَلُوا مَا أَمَرَهُمْ فَأَمَرَ اللَّهُ الْبَرَّ فَجَمَعَ مَا فِيهِ وَأَمَرَ الْبَحْرَ فَجَمَعَ مَا فِيهِ ثُمَّ قَالَ لِمَ فَعَلْتَ هَذَا قَالَ مِنْ خَشْيَتِكَ يَا رَبِّ وَأَنْتَ أَعْلَمُ ‏.‏ فَغَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏\hadithno{6980}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that a person who had never done any good deed asked the members of his family to burn his dead body when he would die and to scatter half of its ashes over the land and half in the ocean. By Allah, if Allah finds him in His grip, He would torment him with a torment with which He did not afflict anyone amongst the people of the world; and when the person died, it was done to him as he had commanded (his family) to do. Allah commanded the land to collect (the ashes scattered on it) and He commanded the ocean and that collected (ashes) contained in it. Allah questioned him why he had done. that He said:My Lord, it is out of Thine fear that I have done it and Thou art well aware of it, and Allah granted him pardon:}}
\hadithdefcmd{muslim}{6982}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ عَبْدٌ أَخْبَرَنَا وَقَالَ ابْنُ رَافِعٍ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، قَالَ قَالَ لِيَ الزُّهْرِيُّ أَلاَ أُحَدِّثُكَ بِحَدِيثَيْنِ عَجِيبَيْنِ قَالَ الزُّهْرِيُّ أَخْبَرَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ أَسْرَفَ رَجُلٌ عَلَى نَفْسِهِ فَلَمَّا حَضَرَهُ الْمَوْتُ أَوْصَى بَنِيهِ فَقَالَ إِذَا أَنَا مُتُّ فَأَحْرِقُونِي ثُمَّ اسْحَقُونِي ثُمَّ اذْرُونِي فِي الرِّيحِ فِي الْبَحْرِ فَوَاللَّهِ لَئِنْ قَدَرَ عَلَىَّ رَبِّي لَيُعَذِّبُنِي عَذَابًا مَا عَذَّبَهُ بِهِ أَحَدًا ‏.‏ قَالَ فَفَعَلُوا ذَلِكَ بِهِ فَقَالَ لِلأَرْضِ أَدِّي مَا أَخَذْتِ ‏.‏ فَإِذَا هُوَ قَائِمٌ فَقَالَ لَهُ مَا حَمَلَكَ عَلَى مَا صَنَعْتَ فَقَالَ خَشْيَتُكَ يَا رَبِّ - أَوْ قَالَ - مَخَافَتُكَ ‏.‏ فَغَفَرَ لَهُ بِذَلِكَ ‏"‏ ‏.‏ قَالَ الزُّهْرِيُّ وَحَدَّثَنِي حُمَيْدٌ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ دَخَلَتِ امْرَأَةٌ النَّارَ فِي هِرَّةٍ رَبَطَتْهَا فَلاَ هِيَ أَطْعَمَتْهَا وَلاَ هِيَ أَرْسَلَتْهَا تَأْكُلُ مِنْ خَشَاشِ الأَرْضِ حَتَّى مَاتَتْ هَزْلاً ‏"‏ ‏.‏ قَالَ الزُّهْرِيُّ ذَلِكَ لِئَلاَّ يَتَّكِلَ رَجُلٌ وَلاَ يَيْأَسَ رَجُلٌ ‏.‏\hadithno{6982}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that a person committed sin beyond measure and when he was going to die, he left this will:(When I die), bum my dead body and then cast them (the ashes) to the wind and in the ocean. By Allah, if my Lord takes hold of me, He would torment me as He has not tormented anyone else. They did as he had asked them to do. He (the Lord) said to the earth: Return what you have taken. And he was thus restored to his (original form). He (Allah) said to him: What prompted you to do this? He said: My Lord, it was Thine fear or Thine awe, and Allah pardoned him because of this. Abu Huraira reported Allah's Messenger (ﷺ) as saying that a woman was thrown into Hell-Fire because of a cat whom she had tied and did not provide it with food. nor did she set it free to eat vermin of the earth until it died emaciated. Az-Zuhri said: (These two ahadith) show that a person should neither feel confident (of getting into Paradise) because of his deeds, nor should he lose (all hopes) of getting into Paradise}}
\hadithdefcmd{muslim}{6983}{حَدَّثَنِي أَبُو الرَّبِيعِ، سُلَيْمَانُ بْنُ دَاوُدَ حَدَّثَنَا مُحَمَّدُ بْنُ حَرْبٍ، حَدَّثَنِي الزُّبَيْدِيُّ، قَالَ الزُّهْرِيُّ حَدَّثَنِي حُمَيْدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ عَوْفٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَسْرَفَ عَبْدٌ عَلَى نَفْسِهِ ‏"‏ ‏.‏ بِنَحْوِ حَدِيثِ مَعْمَرٍ إِلَى قَوْلِهِ ‏"‏ فَغَفَرَ اللَّهُ لَهُ ‏"‏ ‏.‏ وَلَمْ يَذْكُرْ حَدِيثَ الْمَرْأَةِ فِي قِصَّةِ الْهِرَّةِ وَفِي حَدِيثِ الزُّبَيْدِيِّ قَالَ ‏"‏ فَقَالَ اللَّهُ عَزَّ وَجَلَّ لِكُلِّ شَىْءٍ أَخَذَ مِنْهُ شَيْئًا أَدِّ مَا أَخَذْتَ مِنْهُ ‏"‏ ‏.‏\hadithno{6983}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying that a servant transgressed the litnit in committing sins. The rest of the hadith is the same but there is no mention of the story of the cat in it and in the hadith transmitted on the authority of Ziibaidl (the words are):" Allah, the Exalted and Glorious, said to everything which had taken a part of lies ashes to return what it had taken}}
\hadithdefcmd{muslim}{6984}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، سَمِعَ عُقْبَةَ بْنَ عَبْدِ الْغَافِرِ، يَقُولُ سَمِعْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ، يُحَدِّثُ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ رَجُلاً فِيمَنْ كَانَ قَبْلَكُمْ رَاشَهُ اللَّهُ مَالاً وَوَلَدًا فَقَالَ لِوَلَدِهِ لَتَفْعَلُنَّ مَا آمُرُكُمْ بِهِ أَوْ لأُوَلِّيَنَّ مِيرَاثِي غَيْرَكُمْ إِذَا أَنَا مُتُّ فَأَحْرِقُونِي - وَأَكْثَرُ عِلْمِي أَنَّهُ قَالَ - ثُمَّ اسْحَقُونِي وَاذْرُونِي فِي الرِّيحِ فَإِنِّي لَمْ أَبْتَهِرْ عِنْدَ اللَّهِ خَيْرًا وَإِنَّ اللَّهَ يَقْدِرُ عَلَىَّ أَنْ يُعَذِّبَنِي - قَالَ - فَأَخَذَ مِنْهُمْ مِيثَاقًا فَفَعَلُوا ذَلِكَ بِهِ وَرَبِّي فَقَالَ اللَّهُ مَا حَمَلَكَ عَلَى مَا فَعَلْتَ فَقَالَ مَخَافَتُكَ ‏.‏ قَالَ فَمَا تَلاَفَاهُ غَيْرُهَا ‏"‏ ‏.‏\hadithno{6984}\hadithtrans{Abu Sa'id Khudri reported that Allah's Messenger (ﷺ) said that a person amongst the earlier nations before you was conferred property and children by Allah, He said to his children:'You must do as I command you to do, otherwise I will make others besides you as my inheritors. As I die, burn my body and blow my ashes in the wind as I do not find any merit of mine which would please Allah, and if Allah were to take hold of me, He would punish me. He took a pledge from them and they did as he commanded thein to do. Allah said: What prompted you to do this? He said: My Lord. Thine fear, and Allah did not punish him at all}}
\hadithdefcmd{muslim}{6985}{وَحَدَّثَنَاهُ يَحْيَى بْنُ حَبِيبٍ الْحَارِثِيُّ، حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ قَالَ لِي أَبِي حَدَّثَنَا قَتَادَةُ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْحَسَنُ بْنُ مُوسَى، حَدَّثَنَا شَيْبَانُ، بْنُ عَبْدِ الرَّحْمَنِ ح وَحَدَّثَنَا ابْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا أَبُو عَوَانَةَ، كِلاَهُمَا عَنْ قَتَادَةَ، ذَكَرُوا جَمِيعًا بِإِسْنَادِ شُعْبَةَ نَحْوَ حَدِيثِهِ وَفِي حَدِيثِ شَيْبَانَ وَأَبِي عَوَانَةَ ‏"‏ أَنَّ رَجُلاً مِنَ النَّاسِ رَغَسَهُ اللَّهُ مَالاً وَوَلَدًا ‏"‏ ‏.‏ وَفِي حَدِيثِ التَّيْمِيِّ ‏"‏ فَإِنَّهُ لَمْ يَبْتَئِرْ عِنْدَ اللَّهِ خَيْرًا ‏"‏ ‏.‏ قَالَ فَسَّرَهَا قَتَادَةُ لَمْ يَدَّخِرْ عِنْدَ اللَّهِ خَيْرًا ‏.‏ وَفِي حَدِيثِ شَيْبَانَ ‏"‏ فَإِنَّهُ وَاللَّهِ مَا ابْتَأَرَ عِنْدَ اللَّهِ خَيْرًا ‏"‏ ‏.‏ وَفِي حَدِيثِ أَبِي عَوَانَةَ ‏"‏ مَا امْتَأَرَ ‏"‏ ‏.‏ بِالْمِيمِ ‏.‏\hadithno{6985}\hadithtrans{This hadith has been narrated on the authority of Shu'ba with the chain of transmitters but with a slight variation of wording and Qatada explained the word" lam yasiru" as:" I find no good in store for rxie in the eye of Allah}}
\hadithdefcmd{muslim}{6986}{حَدَّثَنِي عَبْدُ الأَعْلَى بْنُ حَمَّادٍ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ، بْنِ أَبِي طَلْحَةَ عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عَمْرَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِيمَا يَحْكِي عَنْ رَبِّهِ عَزَّ وَجَلَّ قَالَ ‏"‏ أَذْنَبَ عَبْدٌ ذَنْبًا فَقَالَ اللَّهُمَّ اغْفِرْ لِي ذَنْبِي ‏.‏ فَقَالَ تَبَارَكَ وَتَعَالَى أَذْنَبَ عَبْدِي ذَنْبًا فَعَلِمَ أَنَّ لَهُ رَبًّا يَغْفِرُ الذَّنْبَ وَيَأْخُذُ بِالذَّنْبِ ‏.‏ ثُمَّ عَادَ فَأَذْنَبَ فَقَالَ أَىْ رَبِّ اغْفِرْ لِي ذَنْبِي ‏.‏ فَقَالَ تَبَارَكَ وَتَعَالَى عَبْدِي أَذْنَبَ ذَنْبًا فَعَلِمَ أَنَّ لَهُ رَبًّا يَغْفِرُ الذَّنْبَ وَيَأْخُذُ بِالذَّنْبِ ‏.‏ ثُمَّ عَادَ فَأَذْنَبَ فَقَالَ أَىْ رَبِّ اغْفِرْ لِي ذَنْبِي ‏.‏ فَقَالَ تَبَارَكَ وَتَعَالَى أَذْنَبَ عَبْدِي ذَنْبًا فَعَلِمَ أَنَّ لَهُ رَبًّا يَغْفِرُ الذَّنْبَ وَيَأْخُذُ بِالذَّنْبِ وَاعْمَلْ مَا شِئْتَ فَقَدْ غَفَرْتُ لَكَ ‏"‏ ‏.‏ قَالَ عَبْدُ الأَعْلَى لاَ أَدْرِي أَقَالَ فِي الثَّالِثَةِ أَوِ الرَّابِعَةِ ‏"‏ اعْمَلْ مَا شِئْتَ ‏"‏ ‏.‏\hadithno{6986}\hadithtrans{Abu Huraira reported from Allah's Messenger (ﷺ) that his Lord, the Exalted and Glorious, thus said. A servant committed a sin and he said:O Allah, forgive me my sins, and Allah (the Exalted and Glorious) said: My servant commited a sin and then he came to realise that he has a Lord Who forgives the sins and takes to account (the sinner) for the sin. He then again committed a sin and said: My Lord, forgive me my sin, and Allah, the Exalted and High, said: My servant committed a sin and then came to realise that he has a Lord Who would forgive his sin or would take (him) to account for the sin. He again committed a sin and said: My Lord, forgive me for my sin, and Allah (the Exalted and High) said: My servant sas committed a sin and then came to realise that he has a Lord Who forgives the sins or takes (him) to account for sin. O servant, do what you like. I have granted you forgiveness. 'Abd al-A'la said: I do not know whether he said thrice or four times to do" what you desire}}
\hadithdefcmd{muslim}{6987}{قَالَ أَبُو أَحْمَدَ حَدَّثَنِي مُحَمَّدُ بْنُ زَنْجُويَهْ الْقُرَشِيُّ الْقُشَيْرِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى، بْنُ حَمَّادٍ النَّرْسِيُّ بِهَذَا الإِسْنَادِ ‏.‏\hadithno{6987}\hadithtrans{The hadlth has been narrated on the authority of 'Abd al-A'la b. Hammad with the same chain of transmitters}}
\hadithdefcmd{muslim}{6988}{حَدَّثَنِي عَبْدُ بْنُ حُمَيْدٍ، حَدَّثَنِي أَبُو الْوَلِيدِ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا إِسْحَاقُ بْنُ عَبْدِ اللَّهِ، بْنِ أَبِي طَلْحَةَ قَالَ كَانَ بِالْمَدِينَةِ قَاصٌّ يُقَالُ لَهُ عَبْدُ الرَّحْمَنِ بْنُ أَبِي عَمْرَةَ - قَالَ - فَسَمِعْتُهُ يَقُولُ سَمِعْتُ أَبَا هُرَيْرَةَ يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ إِنَّ عَبْدًا أَذْنَبَ ذَنْبًا ‏"‏ ‏.‏ بِمَعْنَى حَدِيثِ حَمَّادِ بْنِ سَلَمَةَ ‏.‏ وَذَكَرَ ثَلاَثَ مَرَّاتٍ ‏"‏ أَذْنَبَ ذَنْبًا ‏"‏ ‏.‏ وَفِي الثَّالِثَةِ ‏"‏ قَدْ غَفَرْتُ لِعَبْدِي فَلْيَعْمَلْ مَا شَاءَ ‏"‏ ‏.‏\hadithno{6988}\hadithtrans{Abu Huraira reported lie heard Allah's Messenger (ﷺ) as saying that a servant committed a sin. The rest of the hadith is the same, but there is a slight variation of wording}}
\hadithdefcmd{muslim}{6991}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ، عُثْمَانُ حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ أَحَدٌ أَحَبَّ إِلَيْهِ الْمَدْحُ مِنَ اللَّهِ مِنْ أَجْلِ ذَلِكَ مَدَحَ نَفْسَهُ وَلَيْسَ أَحَدٌ أَغْيَرَ مِنَ اللَّهِ مِنْ أَجْلِ ذَلِكَ حَرَّمَ الْفَوَاحِشَ ‏"‏ ‏.‏\hadithno{6991}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:Nothing is more loveable to Allah than His praise as He has praised Himself and no one is more self-respecting than Allah Himself and it As because of this that He has prohibited abominable acts}}
\hadithdefcmd{muslim}{6992}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، - وَاللَّفْظُ لَهُ - حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، وَأَبُو مُعَاوِيَةَ عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ أَحَدٌ أَغْيَرَ مِنَ اللَّهِ وَلِذَلِكَ حَرَّمَ الْفَوَاحِشَ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ وَلاَ أَحَدٌ أَحَبَّ إِلَيْهِ الْمَدْحُ مِنَ اللَّهِ ‏"‏ ‏.‏\hadithno{6992}\hadithtrans{Abdullah reported Allah's Messenger (ﷺ) as saying:None is more self-respectidg than Allah and it is because of this that He has prohibited abominable acts-both visible and invisible-and none loves His praise more than Allah Himself}}
\hadithdefcmd{muslim}{6993}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَابْنُ، بَشَّارٍ قَالاَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ عَمْرِو بْنِ مُرَّةَ، قَالَ سَمِعْتُ أَبَا وَائِلٍ، يَقُولُ سَمِعْتُ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، يَقُولُ قُلْتُ لَهُ آنْتَ سَمِعْتَهُ مِنْ عَبْدِ اللَّهِ، قَالَ نَعَمْ وَرَفَعَهُ أَنَّهُ قَالَ ‏ "‏ لاَ أَحَدٌ أَغْيَرَ مِنَ اللَّهِ وَلِذَلِكَ حَرَّمَ الْفَوَاحِشَ مَا ظَهَرَ مِنْهَا وَمَا بَطَنَ وَلاَ أَحَدٌ أَحَبَّ إِلَيْهِ الْمَدْحُ مِنَ اللَّهِ وَلِذَلِكَ مَدَحَ نَفْسَهُ ‏"‏ ‏.‏\hadithno{6993}\hadithtrans{Abdullah b. Mas'ud reported it directly from Allah's Messenger (ﷺ) that he said:None is more self-respecting than Allah and it is because of this that He has prohibited abominable acts-both visible and invisible and nothing is loved by Allah more than the praise of His Ownself and it is because of this that He has praised Himself}}
\hadithdefcmd{muslim}{6994}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَزُهَيْرُ بْنُ حَرْبٍ، وَإِسْحَاقُ بْنُ إِبْرَاهِيمَ، قَالَ إِسْحَاقُ أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ مَالِكِ بْنِ الْحَارِثِ، عَنْ عَبْدِ الرَّحْمَنِ، بْنِ يَزِيدَ عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَيْسَ أَحَدٌ أَحَبَّ إِلَيْهِ الْمَدْحُ مِنَ اللَّهِ عَزَّ وَجَلَّ مِنْ أَجْلِ ذَلِكَ مَدَحَ نَفْسَهُ وَلَيْسَ أَحَدٌ أَغْيَرَ مِنَ اللَّهِ مِنْ أَجْلِ ذَلِكَ حَرَّمَ الْفَوَاحِشَ وَلَيْسَ أَحَدٌ أَحَبَّ إِلَيْهِ الْعُذْرُ مِنَ اللَّهِ مِنْ أَجْلِ ذَلِكَ أَنْزَلَ الْكِتَابَ وَأَرْسَلَ الرُّسُلَ ‏"‏ ‏.‏\hadithno{6994}\hadithtrans{Abdullah b. Mas'ud reported that Allah's Messenger (ﷺ) said:None loves one's own praise more than Allah, the Exalted and Glurious, does. It is because of this that He has praised Himself, and none is more self-respecting than Allah and it is because of this that He has prohibited abominable acts and there is none who is more anxious to accept the apologies of the people than Allah Himself and it is because of this that He has revealed the Book and sent the Messengers}}
\hadithdefcmd{muslim}{6995}{حَدَّثَنَا عَمْرٌو النَّاقِدُ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ ابْنُ عُلَيَّةَ، عَنْ حَجَّاجِ بْنِ أَبِي، عُثْمَانَ قَالَ قَالَ يَحْيَى وَحَدَّثَنِي أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ يَغَارُ وَإِنَّ الْمُؤْمِنَ يَغَارُ وَغَيْرَةُ اللَّهِ أَنْ يَأْتِيَ الْمُؤْمِنُ مَا حَرَّمَ عَلَيْهِ ‏"‏ ‏.‏\hadithno{6995}\hadithtrans{Abu Huraira reported Allah's Messenger (ﷺ) as saying:Allah is self-respecting and a believer is also self-respecting and the respect of Allah is injured if a believer does what He has forbidden him to do}}
\hadithdefcmd{muslim}{6996}{قَالَ يَحْيَى وَحَدَّثَنِي أَبُو سَلَمَةَ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ أَسْمَاءَ بِنْتَ أَبِي بَكْرٍ حَدَّثَتْهُ أَنَّهَا، سَمِعَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لَيْسَ شَىْءٌ أَغْيَرَ مِنَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{6996}\hadithtrans{This hadith has been narrated on the authority of Asma' daughter of Abu Bakr, through another chain of transmitters}}
\hadithdefcmd{muslim}{6997}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو دَاوُدَ، حَدَّثَنَا أَبَانُ بْنُ يَزِيدَ، وَحَرْبُ بْنُ شَدَّادٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ بِمِثْلِ رِوَايَةِ حَجَّاجٍ حَدِيثَ أَبِي هُرَيْرَةَ خَاصَّةً وَلَمْ يَذْكُرْ حَدِيثَ أَسْمَاءَ ‏.‏\hadithno{6997}\hadithtrans{Abu Salama reported from Abu Huraira that he narrated that Allah's Messenger (may peace be upon hin) said:There is none more self-respecting than Allah, the Exalted and Glorious There is no mention of the narration of Asma}}
\hadithdefcmd{muslim}{6998}{وَحَدَّثَنَا مُحَمَّدُ بْنُ أَبِي بَكْرٍ الْمُقَدَّمِيُّ، حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، عَنْ هِشَامٍ، عَنْ يَحْيَى، بْنِ أَبِي كَثِيرٍ عَنْ أَبِي سَلَمَةَ، عَنْ عُرْوَةَ، عَنْ أَسْمَاءَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ لاَ شَىْءَ أَغْيَرُ مِنَ اللَّهِ عَزَّ وَجَلَّ ‏"‏ ‏.‏\hadithno{6998}\hadithtrans{Asma' reported that Allah's Apostle (ﷺ) said:There is none more self-respecting than Allah, the Exalted and Glorious}}
\hadithdefcmd{muslim}{6999}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنِ الْعَلاَءِ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُؤْمِنُ يَغَارُ وَاللَّهُ أَشَدُّ غَيْرًا ‏"‏ ‏.‏\hadithno{6999}\hadithtrans{Abu Huraira reported Allah's Messenger (may peace be upon him ) as saying:A believer is self-respecting and Allah is extremely self-respecting}}
\hadithdefcmd{muslim}{7000}{وَحَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، قَالَ سَمِعْتُ الْعَلاَءَ، بِهَذَا الإِسْنَادِ ‏.‏\hadithno{7000}\hadithtrans{This hadith has been narrated on the authority of Shu'ba through another chain of transmitters}}
\hadithdefcmd{muslim}{7001}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو كَامِلٍ فُضَيْلُ بْنُ حُسَيْنٍ الْجَحْدَرِيُّ كِلاَهُمَا عَنْ يَزِيدَ، بْنِ زُرَيْعٍ - وَاللَّفْظُ لأَبِي كَامِلٍ - حَدَّثَنَا يَزِيدُ، حَدَّثَنَا التَّيْمِيُّ، عَنْ أَبِي عُثْمَانَ، عَنْ عَبْدِ اللَّهِ، بْنِ مَسْعُودٍ أَنَّ رَجُلاً، أَصَابَ مِنِ امْرَأَةٍ قُبْلَةً فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ لَهُ ذَلِكَ - قَالَ - فَنَزَلَتْ ‏\{‏ أَقِمِ الصَّلاَةَ طَرَفَىِ النَّهَارِ وَزُلَفًا مِنَ اللَّيْلِ إِنَّ الْحَسَنَاتِ يُذْهِبْنَ السَّيِّئَاتِ ذَلِكَ ذِكْرَى لِلذَّاكِرِينَ‏\}‏ قَالَ فَقَالَ الرَّجُلُ أَلِيَ هَذِهِ يَا رَسُولَ اللَّهِ قَالَ ‏ "‏ لِمَنْ عَمِلَ بِهَا مِنْ أُمَّتِي ‏"‏ ‏.‏\hadithno{7001}\hadithtrans{Abdullah b. Mas'ud reported that a person kissed a woman and he came to Allah's Apostle (ﷺ) and made a mention of that to him. It was (on this occasion) that this verse was revealed:" And observe prayer at the (two) ends of the day and in the first hours of the night. Surely, good deeds take away evil deeds. That is a reminder for the mindful" (xi. 115). That person said: Allah's Messenger, does it concern me only? He (the Holy Prophet) said: It concerns every one of my Unimah, who acts according to it}}
\hadithdefcmd{muslim}{7002}{حَدَّثَنَا يَحْيَى بْنُ يَحْيَى، وَقُتَيْبَةُ بْنُ سَعِيدٍ، وَأَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ - وَاللَّفْظُ لِيَحْيَى - قَالَ يَحْيَى أَخْبَرَنَا وَقَالَ الآخَرَانِ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ سِمَاكٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، وَالأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي عَالَجْتُ امْرَأَةً فِي أَقْصَى الْمَدِينَةِ وَإِنِّي أَصَبْتُ مِنْهَا مَا دُونَ أَنْ أَمَسَّهَا فَأَنَا هَذَا فَاقْضِ فِيَّ مَا شِئْتَ ‏.‏ فَقَالَ لَهُ عُمَرُ لَقَدْ سَتَرَكَ اللَّهُ لَوْ سَتَرْتَ نَفْسَكَ - قَالَ - فَلَمْ يَرُدَّ النَّبِيُّ صلى الله عليه وسلم شَيْئًا فَقَامَ الرَّجُلُ فَانْطَلَقَ فَأَتْبَعَهُ النَّبِيُّ صلى الله عليه وسلم رَجُلاً دَعَاهُ وَتَلاَ عَلَيْهِ هَذِهِ الآيَةَ ‏\{‏ أَقِمِ الصَّلاَةَ طَرَفَىِ النَّهَارِ وَزُلَفًا مِنَ اللَّيْلِ إِنَّ الْحَسَنَاتِ يُذْهِبْنَ السَّيِّئَاتِ ذَلِكَ ذِكْرَى لِلذَّاكِرِينَ‏\}‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ يَا نَبِيَّ اللَّهِ هَذَا لَهُ خَاصَّةً قَالَ ‏"‏ بَلْ لِلنَّاسِ كَافَّةً ‏"‏ ‏.‏\hadithno{7002}\hadithtrans{Abdullah reported that a person came to Allah's Apostle (ﷺ) and said:Allah's Messenger, I sported with a woman in the outskirts of Medina, and I have committed an offence short of fornication. Here I am (before you), kindly deliver verdict about me which you deem fit. Unar said: Allah concealed your fault. You had better conceal it yourself also. Allah's Apostle (ﷺ), however, gave no reply to him. The man stood up and went away and Allah's Apostle (ﷺ) sent a person after him to call him and be recited this verse:" And observe prayer at the ends of the day and in the first hours of the night. Surely, good deeds take away evil deeds. That is a reminder for the mindful" (xi. 115). A person amongst the people said: Allah's Apostle, does it concern this marn only? Thereupon he (the Holy Prophet) said: No, but the people at large}}
\hadithdefcmd{muslim}{7003}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا أَبُو النُّعْمَانِ الْحَكَمُ بْنُ عَبْدِ اللَّهِ الْعِجْلِيُّ، حَدَّثَنَا شُعْبَةُ، عَنْ سِمَاكِ بْنِ حَرْبٍ، قَالَ سَمِعْتُ إِبْرَاهِيمَ، يُحَدِّثُ عَنْ خَالِهِ الأَسْوَدِ، عَنْ عَبْدِ اللَّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَى حَدِيثِ أَبِي الأَحْوَصِ وَقَالَ فِي حَدِيثِهِ فَقَالَ مُعَاذٌ يَا رَسُولَ اللَّهِ هَذَا لِهَذَا خَاصَّةً أَوْ لَنَا عَامَّةً قَالَ ‏ "‏ بَلْ لَكُمْ عَامَّةً ‏"‏ ‏.‏\hadithno{7003}\hadithtrans{This hadith has been transmitted by Abu al-Ahwas and in this (these words are) also found:Mu'adh said: Allah's Messenger, does it concern this particular case or to all of us? And he (the Holy Prophet) said: Of course, to all of you}}
\hadithdefcmd{muslim}{7004}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا الْمُعْتَمِرُ، عَنْ أَبِيهِ، حَدَّثَنَا أَبُو عُثْمَانَ، عَنِ ابْنِ، مَسْعُودٍ أَنَّ رَجُلاً، أَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ أَنَّهُ أَصَابَ مِنِ امْرَأَةٍ إِمَّا قُبْلَةً أَوْ مَسًّا بِيَدٍ أَوْ شَيْئًا كَأَنَّهُ يَسْأَلُ عَنْ كَفَّارَتِهَا - قَالَ - فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏.‏ ثُمَّ ذَكَرَ بِمِثْلِ حَدِيثِ يَزِيدَ ‏.‏\hadithno{7004}\hadithtrans{Ibn Mas'ud reported that a person came to Allah's Messenger (ﷺ) and told him that he had kissed a woman or touched her with his hand or did something like this. He inquired of him about its expiation. It was (on this occasion) that Allah, the Exalted and Glorious, revealed this verse (as mentioned above)}}
\hadithdefcmd{muslim}{7005}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، بِهَذَا الإِسْنَادِ قَالَ أَصَابَ رَجُلٌ مِنِ امْرَأَةٍ شَيْئًا دُونَ الْفَاحِشَةِ فَأَتَى عُمَرَ بْنَ الْخَطَّابِ فَعَظَّمَ عَلَيْهِ ثُمَّ أَتَى أَبَا بَكْرٍ فَعَظَّمَ عَلَيْهِ ثُمَّ أَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ بِمِثْلِ حَدِيثِ يَزِيدَ وَالْمُعْتَمِرِ ‏.‏\hadithno{7005}\hadithtrans{This hadith has been narrated on the authority of Sulaiman Taimi with the same chain of transmitters that a person had taken liberty with a woman less than fomication. He came to 'Umar b. Khattab and he took it to be a serious offence. Then he came to Abu Bakr and he also took it to be a serious offence. Then he came the Allahs Apostle (ﷺ) and he made a mention of this to him. The rest of the hadith is the same}}
\hadithdefcmd{muslim}{7006}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْحُلْوَانِيُّ، حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، حَدَّثَنَا هَمَّامٌ، عَنْ إِسْحَاقَ، بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ عَنْ أَنَسٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ أَصَبْتُ حَدًّا فَأَقِمْهُ عَلَىَّ - قَالَ - وَحَضَرَتِ الصَّلاَةُ فَصَلَّى مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا قَضَى الصَّلاَةَ قَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ حَدًّا فَأَقِمْ فِيَّ كِتَابَ اللَّهِ ‏.‏ قَالَ ‏"‏ هَلْ حَضَرْتَ الصَّلاَةَ مَعَنَا ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ قَالَ ‏"‏ قَدْ غُفِرَ لَكَ ‏"‏ ‏.‏\hadithno{7006}\hadithtrans{Anas reported that a person came to Allah's Apostle (ﷺ) said:Allah's Messenger, I have committed an offence which deserves imposition of haad, so impose it upon me according to the Book of Allah. Thereupon he said: Were you not present with us at the time of prayer? He said: Yes. Thereupon he said: You have been granted pardon}}
\hadithdefcmd{muslim}{7007}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَزُهَيْرُ بْنُ حَرْبٍ، - وَاللَّفْظُ لِزُهَيْرٍ - قَالاَ حَدَّثَنَا عُمَرُ بْنُ يُونُسَ، حَدَّثَنَا عِكْرِمَةُ بْنُ عَمَّارٍ، حَدَّثَنَا شَدَّادٌ، حَدَّثَنَا أَبُو أُمَامَةَ، قَالَ بَيْنَمَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي الْمَسْجِدِ وَنَحْنُ قُعُودٌ مَعَهُ إِذْ جَاءَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ حَدًّا فَأَقِمْهُ عَلَىَّ ‏.‏ فَسَكَتَ عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ أَعَادَ فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ حَدًّا فَأَقِمْهُ عَلَىَّ ‏.‏ فَسَكَتَ عَنْهُ وَأُقِيمَتِ الصَّلاَةُ فَلَمَّا انْصَرَفَ نَبِيُّ اللَّهِ صلى الله عليه وسلم قَالَ أَبُو أُمَامَةَ فَاتَّبَعَ الرَّجُلُ رَسُولَ اللَّهِ صلى الله عليه وسلم حِينَ انْصَرَفَ وَاتَّبَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَنْظُرُ مَا يَرُدُّ عَلَى الرَّجُلِ فَلَحِقَ الرَّجُلُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي أَصَبْتُ حَدًّا فَأَقِمْهُ عَلَىَّ - قَالَ أَبُو أُمَامَةَ - فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَرَأَيْتَ حِينَ خَرَجْتَ مِنْ بَيْتِكَ أَلَيْسَ قَدْ تَوَضَّأْتَ فَأَحْسَنْتَ الْوُضُوءَ ‏"‏ ‏.‏ قَالَ بَلَى يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ ثُمَّ شَهِدْتَ الصَّلاَةَ مَعَنَا ‏"‏ ‏.‏ فَقَالَ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَإِنَّ اللَّهَ قَدْ غَفَرَ لَكَ حَدَّكَ - أَوْ قَالَ - ذَنْبَكَ ‏"‏ ‏.‏\hadithno{7007}\hadithtrans{Abu Umama reported:We were sitting in the mosque in the company of Allah's Messenger (ﷺ). A person came there and said: Allah's Messenger, I have committed an offence which deserves the imposition of hadd upon me, so impose it upon me. Allah's Messenger (ﷺ) kept silent. He repeated it and said: Allah's Messenger, I have committed an offence which deserves the imposition of hadd upon me, so impose it upon me. He (the Holy Prophet) kept silent, and it was at this time that Iqama was pronounced for prayer (and the prayer was observed). And when Allah's Apostle (ﷺ) had concluded the payer that person followed Allah's Messenger (ﷺ). Abu Umama said: I too followed Allah's Messenger (ﷺ) after he had concluded the prayer, so that I should know what answer he would give to that person. That person remained attached to Allah's Messenger (ﷺ) and said: Allah's Messenger, I have committed an offence which deserves imposition of hadd upon me, so impose it upon me. Abu Umama reported that Allah's Messenger (ﷺ) said to him: Didn't you see that as you got out of the house, you performed ablution perfectly well. He said: Allah's Messenger, of course. I did it. He again said to him: Then you observed prayer along with us. He said: Allah's Messenger, yes, it is so. Thereupon Allah's Messenger (ﷺ) said to him: Verily, Allah has exempted you from the imposition of hadd, or he said. From your sin}}
\hadithdefcmd{muslim}{7008}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، وَمُحَمَّدُ بْنُ بَشَّارٍ، - وَاللَّفْظُ لاِبْنِ الْمُثَنَّى - قَالَ حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، عَنْ أَبِي الصِّدِّيقِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ كَانَ فِيمَنْ كَانَ قَبْلَكُمْ رَجُلٌ قَتَلَ تِسْعَةً وَتِسْعِينَ نَفْسًا فَسَأَلَ عَنْ أَعْلَمِ أَهْلِ الأَرْضِ فَدُلَّ عَلَى رَاهِبٍ فَأَتَاهُ فَقَالَ إِنَّهُ قَتَلَ تِسْعَةً وَتِسْعِينَ نَفْسًا فَهَلْ لَهُ مِنَ تَوْبَةٍ فَقَالَ لاَ ‏.‏ فَقَتَلَهُ فَكَمَّلَ بِهِ مِائَةً ثُمَّ سَأَلَ عَنْ أَعْلَمِ أَهْلِ الأَرْضِ فَدُلَّ عَلَى رَجُلٍ عَالِمٍ فَقَالَ إِنَّهُ قَتَلَ مِائَةَ نَفْسٍ فَهَلْ لَهُ مِنْ تَوْبَةٍ فَقَالَ نَعَمْ وَمَنْ يَحُولُ بَيْنَهُ وَبَيْنَ التَّوْبَةِ انْطَلِقْ إِلَى أَرْضِ كَذَا وَكَذَا فَإِنَّ بِهَا أُنَاسًا يَعْبُدُونَ اللَّهَ فَاعْبُدِ اللَّهَ مَعَهُمْ وَلاَ تَرْجِعْ إِلَى أَرْضِكَ فَإِنَّهَا أَرْضُ سَوْءٍ ‏.‏ فَانْطَلَقَ حَتَّى إِذَا نَصَفَ الطَّرِيقَ أَتَاهُ الْمَوْتُ فَاخْتَصَمَتْ فِيهِ مَلاَئِكَةُ الرَّحْمَةِ وَمَلاَئِكَةُ الْعَذَابِ فَقَالَتْ مَلاَئِكَةُ الرَّحْمَةِ جَاءَ تَائِبًا مُقْبِلاً بِقَلْبِهِ إِلَى اللَّهِ ‏.‏ وَقَالَتْ مَلاَئِكَةُ الْعَذَابِ إِنَّهُ لَمْ يَعْمَلْ خَيْرًا قَطُّ ‏.‏ فَأَتَاهُمْ مَلَكٌ فِي صُورَةِ آدَمِيٍّ فَجَعَلُوهُ بَيْنَهُمْ فَقَالَ قِيسُوا مَا بَيْنَ الأَرْضَيْنِ فَإِلَى أَيَّتِهِمَا كَانَ أَدْنَى فَهُوَ لَهُ ‏.‏ فَقَاسُوهُ فَوَجَدُوهُ أَدْنَى إِلَى الأَرْضِ الَّتِي أَرَادَ فَقَبَضَتْهُ مَلاَئِكَةُ الرَّحْمَةِ ‏"‏ ‏.‏ قَالَ قَتَادَةُ فَقَالَ الْحَسَنُ ذُكِرَ لَنَا أَنَّهُ لَمَّا أَتَاهُ الْمَوْتُ نَأَى بِصَدْرِهِ ‏.‏\hadithno{7008}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying:There was a person before you who had killed ninety-nine persons and then made an inquiry about the learned persons of the world (who could show him the way to salvation). He was directed to a monk. He came to him and told him that he had killed ninety-nine persons and asked him whether there was any scope for his repentance to be accepted. He said: No. He killed him also and thus completed one hundred. He then asked about the learned persons of the earth and he was directed to a scholar, and he told him that he had killed one hundred persons and asked him whether there was any scope for his repentance to be accepted. He said: Yes; what stands between you and the repentance? You better go to such and such land; there are people devoted to prayer and worship and you also worship along with them and do not come to the land of yours since it was an evil land (for you). So he went away and he had hardly covered half the distance when death came to him and there was a dispute between the angels of mercy and the angels of punishment. The angels of mercy said: This man has come as a penitant and remorseful to Allah and the angels of punishment said: He has done no good at all. Then there came another angel in the form of a human being in order to decide between them. He said: You measure the land to which he has drawn near. They measured it and found him nearer to the land where he intended to go (the land of piety), and so the angels of mercy took possession of it. Qatada said that Hasan told him that it was said to them that as death approached him, he crawled upon his chest (and managed) to slip in the land of mercy}}
\hadithdefcmd{muslim}{7009}{حَدَّثَنِي عُبَيْدُ اللَّهِ بْنُ مُعَاذٍ الْعَنْبَرِيُّ، حَدَّثَنَا أَبِي، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، أَنَّهُ سَمِعَ أَبَا الصِّدِّيقِ النَّاجِيَّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ أَنَّ رَجُلاً قَتَلَ تِسْعَةً وَتِسْعِينَ نَفْسًا فَجَعَلَ يَسْأَلُ هَلْ لَهُ مِنْ تَوْبَةٍ فَأَتَى رَاهِبًا فَسَأَلَهُ فَقَالَ لَيْسَتْ لَكَ تَوْبَةٌ ‏.‏ فَقَتَلَ الرَّاهِبَ ثُمَّ جَعَلَ يَسْأَلُ ثُمَّ خَرَجَ مِنْ قَرْيَةٍ إِلَى قَرْيَةٍ فِيهَا قَوْمٌ صَالِحُونَ فَلَمَّا كَانَ فِي بَعْضِ الطَّرِيقِ أَدْرَكَهُ الْمَوْتُ فَنَأَى بِصَدْرِهِ ثُمَّ مَاتَ فَاخْتَصَمَتْ فِيهِ مَلاَئِكَةُ الرَّحْمَةِ وَمَلاَئِكَةُ الْعَذَابِ فَكَانَ إِلَى الْقَرْيَةِ الصَّالِحَةِ أَقْرَبَ مِنْهَا بِشِبْرٍ فَجُعِلَ مِنْ أَهْلِهَا ‏"‏ ‏.‏\hadithno{7009}\hadithtrans{Abu Sa'id al-Khudri reported Allah's Messenger (ﷺ) as saying that a man killed ninety-nine persons and then he began to make an inquiry whether there was any way left for him for repentance. He came to a monk and asked him about that, and he said:There is no chance for repentance for you. He killed the monk also and then began to make an inquiry and moved from one village to another village where there lived pious persons, and as he had covered some distance, he was overtaken by death, but he managed to crawl upon his chest (to the side nearer to the place where the pious men lived). He died and then there was a dispute between the angels of mercy and the angels of punishment and (when it was measured) he was found to be nearer to the village where pious persons were living equal to the Space of a span and he was thus included among them}}
\hadithdefcmd{muslim}{7010}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ مُعَاذِ بْنِ مُعَاذٍ وَزَادَ فِيهِ ‏ "‏ فَأَوْحَى اللَّهُ إِلَى هَذِهِ أَنْ تَبَاعَدِي وَإِلَى هَذِهِ أَنْ تَقَرَّبِي ‏"‏ ‏.‏\hadithno{7010}\hadithtrans{This hadith has been narrated on the authority of Qatida with the same chain of transmitters but (with this variation of wording):" Allah commanded the earth (from where) he wanted to come out to move itself away and to the other earth (where he wanted to go) to draw nearer}}
\hadithdefcmd{muslim}{7011}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ طَلْحَةَ بْنِ يَحْيَى، عَنْ أَبِي، بُرْدَةَ عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا كَانَ يَوْمُ الْقِيَامَةِ دَفَعَ اللَّهُ عَزَّ وَجَلَّ إِلَى كُلِّ مُسْلِمٍ يَهُودِيًّا أَوْ نَصْرَانِيًّا فَيَقُولُ هَذَا فَكَاكُكَ مِنَ النَّارِ ‏"‏ ‏.‏\hadithno{7011}\hadithtrans{Abu Musa' reported that Allah's Messenger (ﷺ) said:When it will be the Day of Resurrection Allah would deliver to every Muslim a Jew or a Christian and say: That is your rescue from Hell-Fire}}
\hadithdefcmd{muslim}{7012}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ بْنُ مُسْلِمٍ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، أَنَّ عَوْنًا، وَسَعِيدَ بْنَ أَبِي بُرْدَةَ، حَدَّثَاهُ أَنَّهُمَا، شَهِدَا أَبَا بُرْدَةَ يُحَدِّثُ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَمُوتُ رَجُلٌ مُسْلِمٌ إِلاَّ أَدْخَلَ اللَّهُ مَكَانَهُ النَّارَ يَهُودِيًّا أَوْ نَصْرَانِيًّا ‏"‏ ‏.‏ قَالَ فَاسْتَحْلَفَهُ عُمَرُ بْنُ عَبْدِ الْعَزِيزِ بِاللَّهِ الَّذِي لاَ إِلَهَ إِلاَّ هُوَ ثَلاَثَ مَرَّاتٍ أَنَّ أَبَاهُ حَدَّثَهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ فَحَلَفَ لَهُ - قَالَ - فَلَمْ يُحَدِّثْنِي سَعِيدٌ أَنَّهُ اسْتَحْلَفَهُ وَلَمْ يُنْكِرْ عَلَى عَوْنٍ قَوْلَهُ ‏.‏\hadithno{7012}\hadithtrans{Abu Burda reported on the authority of his father that Allah's Apostle (ﷺ) said:No Muslim would die but Allah would admit in his stead a Jew or a Christian in Hell-Fire. 'Umar b. Abd al-'Aziz took an oath: By One besides Whom there is no god but He, thrice that his father had narrated that to him from Allah's Messenger (ﷺ)}}
\hadithdefcmd{muslim}{7013}{حَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، جَمِيعًا عَنْ عَبْدِ الصَّمَدِ بْنِ عَبْدِ، الْوَارِثِ أَخْبَرَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، بِهَذَا الإِسْنَادِ نَحْوَ حَدِيثِ عَفَّانَ وَقَالَ عَوْنُ بْنُ عُتْبَةَ ‏.‏\hadithno{7013}\hadithtrans{This hadith has been transmitted on the authority of 'Aun b. Utba}}
\hadithdefcmd{muslim}{7014}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرِو بْنِ عَبَّادِ بْنِ جَبَلَةَ بْنِ أَبِي رَوَّادٍ، حَدَّثَنَا حَرَمِيُّ بْنُ عُمَارَةَ، حَدَّثَنَا شَدَّادٌ أَبُو طَلْحَةَ الرَّاسِبِيُّ، عَنْ غَيْلاَنَ بْنِ جَرِيرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ يَجِيءُ يَوْمَ الْقِيَامَةِ نَاسٌ مِنَ الْمُسْلِمِينَ بِذُنُوبٍ أَمْثَالِ الْجِبَالِ فَيَغْفِرُهَا اللَّهُ لَهُمْ وَيَضَعُهَا عَلَى الْيَهُودِ وَالنَّصَارَى ‏"‏ ‏.‏ فِيمَا أَحْسِبُ أَنَا ‏.‏ قَالَ أَبُو رَوْحٍ لاَ أَدْرِي مِمَّنِ الشَّكُّ ‏.‏ قَالَ أَبُو بُرْدَةَ فَحَدَّثْتُ بِهِ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ فَقَالَ أَبُوكَ حَدَّثَكَ هَذَا عَنِ النَّبِيِّ صلى الله عليه وسلم قُلْتُ نَعَمْ ‏.‏\hadithno{7014}\hadithtrans{Abu Burda reported Allah's Messenger (ﷺ) as saying:There would come people amongst the Muslims on the Day of Resurrection with as heavy sins as a mountain, and Allah would forgive them and He would place in their stead the Jews and the Christians. (As far as I think), Abu Raub said: I do not know as to who is in doubt. Abu Burda said: I narrated it to 'Umar b. 'Abd al-'Aziz, whereupon he said: Was it your father who narrated it to you from Allah's Apostle (ﷺ)? I said: Yes}}
\hadithdefcmd{muslim}{7015}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ هِشَامٍ الدَّسْتَوَائِيِّ، عَنْ قَتَادَةَ، عَنْ صَفْوَانَ بْنِ مُحْرِزٍ، قَالَ قَالَ رَجُلٌ لاِبْنِ عُمَرَ كَيْفَ سَمِعْتَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ فِي النَّجْوَى قَالَ سَمِعْتُهُ يَقُولُ ‏ "‏ يُدْنَى الْمُؤْمِنُ يَوْمَ الْقِيَامَةِ مِنْ رَبِّهِ عَزَّ وَجَلَّ حَتَّى يَضَعَ عَلَيْهِ كَنَفَهُ فَيُقَرِّرُهُ بِذُنُوبِهِ فَيَقُولُ هَلْ تَعْرِفُ فَيَقُولُ أَىْ رَبِّ أَعْرِفُ ‏.‏ قَالَ فَإِنِّي قَدْ سَتَرْتُهَا عَلَيْكَ فِي الدُّنْيَا وَإِنِّي أَغْفِرُهَا لَكَ الْيَوْمَ ‏.‏ فَيُعْطَى صَحِيفَةَ حَسَنَاتِهِ وَأَمَّا الْكُفَّارُ وَالْمُنَافِقُونَ فَيُنَادَى بِهِمْ عَلَى رُءُوسِ الْخَلاَئِقِ هَؤُلاَءِ الَّذِينَ كَذَبُوا عَلَى اللَّهِ ‏"‏ ‏.‏\hadithno{7015}\hadithtrans{Safwan b. Muhriz reported that a person said to Ibn 'Umar:How did you hear Allah's Messenger (ﷺ) as saying something about intimate conversation? He said: I heard him say: A believer will be brought to his Lord, the Exalted and Glorious, on the Day of Resurrection and He would place upon him His veil (of Light) and make him confess his faults and say: Do you recognise (your faults)? He would say: My Lord, I do recognise (them). He (the Lord) would say: I concealed them for you in the world. And today I forgive them. And he would then be given the Book containing (the account of his) good deeds. And so far as the non-believers and hypocrites are concerned, there would be general announcement about them before all creation telling them that these (people, i. e. non-believers and hypocrites) told a lie about Allah}}
\hadithdefcmd{muslim}{7019}{وَحَدَّثَنِي سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا الْحَسَنُ بْنُ أَعْيَنَ، حَدَّثَنَا مَعْقِلٌ، - وَهُوَ ابْنُ عُبَيْدِ اللَّهِ - عَنِ الزُّهْرِيِّ، أَخْبَرَنِي عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ عَمِّهِ، عُبَيْدِ اللَّهِ بْنِ كَعْبٍ وَكَانَ قَائِدَ كَعْبٍ حِينَ أُصِيبَ بَصَرُهُ وَكَانَ أَعْلَمَ قَوْمِهِ وَأَوْعَاهُمْ لأَحَادِيثِ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ سَمِعْتُ أَبِي كَعْبَ بْنَ مَالِكٍ وَهُوَ أَحَدُ الثَّلاَثَةِ الَّذِينَ تِيبَ عَلَيْهِمْ يُحَدِّثُ أَنَّهُ لَمْ يَتَخَلَّفْ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةٍ غَزَاهَا قَطُّ غَيْرَ غَزْوَتَيْنِ ‏.‏ وَسَاقَ الْحَدِيثَ وَقَالَ فِيهِ وَغَزَا رَسُولُ اللَّهِ صلى الله عليه وسلم بِنَاسٍ كَثِيرٍ يَزِيدُونَ عَلَى عَشْرَةِ آلاَفٍ وَلاَ يَجْمَعُهُمْ دِيوَانُ حَافِظٍ ‏.‏\hadithno{7019}\hadithtrans{It is reported on the authority of Abdullah b. K'ab and he was the guide of Ka'b as he lost his eyesight and he was the greatest scholar amongst his people and he retained in his mind many ahadith of the Companions of Allah's Messenger (ﷺ). He said:I heard my father Ka'b b. Malik, and he fas one of those three whose repentance was accepted (by Allah). He transmitted that He never lagged behind Allah's Messenger (ﷺ) from any expedition that he undertook except two expeditions; the rest of the hadith is the same, and in the tradition narrated through another chain of transmitters the words are:" That Allah's Messenger (ﷺ) set out on an expedition with a large number of persons more than ten thousand and this could not be recorded in the census register}}
\hadithdefcmd{muslim}{7021}{حَدَّثَنَا حَبَّانُ بْنُ مُوسَى، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا يُونُسُ بْنُ يَزِيدَ، الأَيْلِيُّ ح وَحَدَّثَنَا إِسْحَاقُ بْنُ إِبْرَاهِيمَ الْحَنْظَلِيُّ، وَمُحَمَّدُ بْنُ رَافِعٍ، وَعَبْدُ بْنُ حُمَيْدٍ، قَالَ ابْنُ رَافِعٍ حَدَّثَنَا وَقَالَ الآخَرَانِ، أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، وَالسِّيَاقُ، حَدِيثُ مَعْمَرٍ مِنْ رِوَايَةِ عَبْدٍ وَابْنِ رَافِعٍ قَالَ يُونُسُ وَمَعْمَرٌ جَمِيعًا عَنِ الزُّهْرِيِّ أَخْبَرَنِي سَعِيدُ بْنُ الْمُسَيَّبِ وَعُرْوَةُ بْنُ الزُّبَيْرِ وَعَلْقَمَةُ بْنِ وَقَّاصٍ وَعُبَيْدُ اللَّهِ بْنُ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ عَنْ حَدِيثِ عَائِشَةَ زَوْجِ النَّبِيِّ صلى الله عليه وسلم حِينَ قَالَ لَهَا أَهْلُ الإِفْكِ مَا قَالُوا فَبَرَّأَهَا اللَّهُ مِمَّا قَالُوا وَكُلُّهُمْ حَدَّثَنِي طَائِفَةً مِنْ حَدِيثِهَا وَبَعْضُهُمْ كَانَ أَوْعَى لِحَدِيثِهَا مِنْ بَعْضٍ وَأَثْبَتَ اقْتِصَاصًا وَقَدْ وَعَيْتُ عَنْ كُلِّ وَاحِدٍ مِنْهُمُ الْحَدِيثَ الَّذِي حَدَّثَنِي وَبَعْضُ حَدِيثِهِمْ يُصَدِّقُ بَعْضًا ذَكَرُوا أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ أَنْ يَخْرُجَ سَفَرًا أَقْرَعَ بَيْنَ نِسَائِهِ فَأَيَّتُهُنَّ خَرَجَ سَهْمُهَا خَرَجَ بِهَا رَسُولُ اللَّهِ صلى الله عليه وسلم مَعَهُ - قَالَتْ عَائِشَةُ - فَأَقْرَعَ بَيْنَنَا فِي غَزْوَةٍ غَزَاهَا فَخَرَجَ فِيهَا سَهْمِي فَخَرَجْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَذَلِكَ بَعْدَ مَا أُنْزِلَ الْحِجَابُ فَأَنَا أُحْمَلُ فِي هَوْدَجِي وَأُنْزَلُ فِيهِ مَسِيرَنَا حَتَّى إِذَا فَرَغَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ غَزْوِهِ وَقَفَلَ وَدَنَوْنَا مِنَ الْمَدِينَةِ آذَنَ لَيْلَةً بِالرَّحِيلِ فَقُمْتُ حِينَ آذَنُوا بِالرَّحِيلِ فَمَشَيْتُ حَتَّى جَاوَزْتُ الْجَيْشَ فَلَمَّا قَضَيْتُ مِنْ شَأْنِي أَقْبَلْتُ إِلَى الرَّحْلِ فَلَمَسْتُ صَدْرِي فَإِذَا عِقْدِي مِنْ جَزْعِ ظَفَارِ قَدِ انْقَطَعَ فَرَجَعْتُ فَالْتَمَسْتُ عِقْدِي فَحَبَسَنِي ابْتِغَاؤُهُ وَأَقْبَلَ الرَّهْطُ الَّذِينَ كَانُوا يَرْحَلُونَ لِي فَحَمَلُوا هَوْدَجِي فَرَحَلُوهُ عَلَى بَعِيرِيَ الَّذِي كُنْتُ أَرْكَبُ وَهُمْ يَحْسَبُونَ أَنِّي فِيهِ - قَالَتْ - وَكَانَتِ النِّسَاءُ إِذْ ذَاكَ خِفَافًا لَمْ يُهَبَّلْنَ وَلَمْ يَغْشَهُنَّ اللَّحْمُ إِنَّمَا يَأْكُلْنَ الْعُلْقَةَ مِنَ الطَّعَامِ فَلَمْ يَسْتَنْكِرِ الْقَوْمُ ثِقَلَ الْهَوْدَجِ حِينَ رَحَلُوهُ وَرَفَعُوهُ وَكُنْتُ جَارِيَةً حَدِيثَةَ السِّنِّ فَبَعَثُوا الْجَمَلَ وَسَارُوا وَوَجَدْتُ عِقْدِي بَعْدَ مَا اسْتَمَرَّ الْجَيْشُ فَجِئْتُ مَنَازِلَهُمْ وَلَيْسَ بِهَا دَاعٍ وَلاَ مُجِيبٌ فَتَيَمَّمْتُ مَنْزِلِي الَّذِي كُنْتُ فِيهِ وَظَنَنْتُ أَنَّ الْقَوْمَ سَيَفْقِدُونِي فَيَرْجِعُونَ إِلَىَّ فَبَيْنَا أَنَا جَالِسَةٌ فِي مَنْزِلِي غَلَبَتْنِي عَيْنِي فَنِمْتُ وَكَانَ صَفْوَانُ بْنُ الْمُعَطَّلِ السُّلَمِيُّ ثُمَّ الذَّكْوَانِيُّ قَدْ عَرَّسَ مِنْ وَرَاءِ الْجَيْشِ فَادَّلَجَ فَأَصْبَحَ عِنْدَ مَنْزِلِي فَرَأَى سَوَادَ إِنْسَانٍ نَائِمٍ فَأَتَانِي فَعَرَفَنِي حِينَ رَآنِي وَقَدْ كَانَ يَرَانِي قَبْلَ أَنْ يُضْرَبَ الْحِجَابُ عَلَىَّ فَاسْتَيْقَظْتُ بِاسْتِرْجَاعِهِ حِينَ عَرَفَنِي فَخَمَّرْتُ وَجْهِي بِجِلْبَابِي وَوَاللَّهِ مَا يُكَلِّمُنِي كَلِمَةً وَلاَ سَمِعْتُ مِنْهُ كَلِمَةً غَيْرَ اسْتِرْجَاعِهِ حَتَّى أَنَاخَ رَاحِلَتَهُ فَوَطِئَ عَلَى يَدِهَا فَرَكِبْتُهَا فَانْطَلَقَ يَقُودُ بِي الرَّاحِلَةَ حَتَّى أَتَيْنَا الْجَيْشَ بَعْدَ مَا نَزَلُوا مُوغِرِينَ فِي نَحْرِ الظَّهِيرَةِ فَهَلَكَ مَنْ هَلَكَ فِي شَأْنِي وَكَانَ الَّذِي تَوَلَّى كِبْرَهُ عَبْدُ اللَّهِ بْنُ أُبَىٍّ ابْنُ سَلُولَ فَقَدِمْنَا الْمَدِينَةَ فَاشْتَكَيْتُ حِينَ قَدِمْنَا الْمَدِينَةَ شَهْرًا وَالنَّاسُ يُفِيضُونَ فِي قَوْلِ أَهْلِ الإِفْكِ وَلاَ أَشْعُرُ بِشَىْءٍ مِنْ ذَلِكَ وَهُوَ يَرِيبُنِي فِي وَجَعِي أَنِّي لاَ أَعْرِفُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم اللُّطْفَ الَّذِي كُنْتُ أَرَى مِنْهُ حِينَ أَشْتَكِي إِنَّمَا يَدْخُلُ رَسُولُ اللَّهِ صلى الله عليه وسلم فَيُسَلِّمُ ثُمَّ يَقُولُ ‏"‏ كَيْفَ تِيكُمْ ‏"‏ ‏.‏ فَذَاكَ يَرِيبُنِي وَلاَ أَشْعُرُ بِالشَّرِّ حَتَّى خَرَجْتُ بَعْدَ مَا نَقِهْتُ وَخَرَجَتْ مَعِي أُمُّ مِسْطَحٍ قِبَلَ الْمَنَاصِعِ وَهُوَ مُتَبَرَّزُنَا وَلاَ نَخْرُجُ إِلاَّ لَيْلاً إِلَى لَيْلٍ وَذَلِكَ قَبْلَ أَنَّ نَتَّخِذَ الْكُنُفَ قَرِيبًا مِنْ بُيُوتِنَا وَأَمْرُنَا أَمْرُ الْعَرَبِ الأُوَلِ فِي التَّنَزُّهِ وَكُنَّا نَتَأَذَّى بِالْكُنُفِ أَنْ نَتَّخِذَهَا عِنْدَ بُيُوتِنَا فَانْطَلَقْتُ أَنَا وَأُمُّ مِسْطَحٍ وَهِيَ بِنْتُ أَبِي رُهْمِ بْنِ الْمُطَّلِبِ بْنِ عَبْدِ مَنَافٍ وَأُمُّهَا ابْنَةُ صَخْرِ بْنِ عَامِرٍ خَالَةُ أَبِي بَكْرٍ الصِّدِّيقِ وَابْنُهَا مِسْطَحُ بْنُ أُثَاثَةَ بْنِ عَبَّادِ بْنِ الْمُطَّلِبِ فَأَقْبَلْتُ أَنَا وَبِنْتُ أَبِي رُهْمٍ قِبَلَ بَيْتِي حِينَ فَرَغْنَا مِنْ شَأْنِنَا فَعَثَرَتْ أُمُّ مِسْطَحٍ فِي مِرْطِهَا فَقَالَتْ تَعِسَ مِسْطَحٌ ‏.‏ فَقُلْتُ لَهَا بِئْسَ مَا قُلْتِ أَتَسُبِّينَ رَجُلاً قَدْ شَهِدَ بَدْرًا ‏.‏ قَالَتْ أَىْ هَنْتَاهُ أَوَلَمْ تَسْمَعِي مَا قَالَ قُلْتُ وَمَاذَا قَالَ قَالَتْ فَأَخْبَرَتْنِي بِقَوْلِ أَهْلِ الإِفْكِ فَازْدَدْتُ مَرَضًا إِلَى مَرَضِي فَلَمَّا رَجَعْتُ إِلَى بَيْتِي فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَلَّمَ ثُمَّ قَالَ ‏"‏ كَيْفَ تِيكُمْ ‏"‏ ‏.‏ قُلْتُ أَتَأْذَنُ لِي أَنْ آتِيَ أَبَوَىَّ قَالَتْ وَأَنَا حِينَئِذٍ أُرِيدُ أَنْ أَتَيَقَّنَ الْخَبَرَ مِنْ قِبَلِهِمَا ‏.‏ فَأَذِنَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَجِئْتُ أَبَوَىَّ فَقُلْتُ لأُمِّي يَا أُمَّتَاهْ مَا يَتَحَدَّثُ النَّاسُ فَقَالَتْ يَا بُنَيَّةُ هَوِّنِي عَلَيْكِ فَوَاللَّهِ لَقَلَّمَا كَانَتِ امْرَأَةٌ قَطُّ وَضِيئَةٌ عِنْدَ رَجُلٍ يُحِبُّهَا وَلَهَا ضَرَائِرُ إِلاَّ كَثَّرْنَ عَلَيْهَا - قَالَتْ - قُلْتُ سُبْحَانَ اللَّهِ وَقَدْ تَحَدَّثَ النَّاسُ بِهَذَا قَالَتْ فَبَكَيْتُ تِلْكَ اللَّيْلَةَ حَتَّى أَصْبَحْتُ لاَ يَرْقَأُ لِي دَمْعٌ وَلاَ أَكْتَحِلُ بِنَوْمٍ ثُمَّ أَصَبَحْتُ أَبْكِي وَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلِيَّ بْنَ أَبِي طَالِبٍ وَأُسَامَةَ بْنَ زَيْدٍ حِينَ اسْتَلْبَثَ الْوَحْىُ يَسْتَشِيرُهُمَا فِي فِرَاقِ أَهْلِهِ - قَالَتْ - فَأَمَّا أُسَامَةُ بْنُ زَيْدٍ فَأَشَارَ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم بِالَّذِي يَعْلَمُ مِنْ بَرَاءَةِ أَهْلِهِ وَبِالَّذِي يَعْلَمُ فِي نَفْسِهِ لَهُمْ مِنَ الْوُدِّ فَقَالَ يَا رَسُولَ اللَّهِ هُمْ أَهْلُكَ وَلاَ نَعْلَمُ إِلاَّ خَيْرًا ‏.‏ وَأَمَّا عَلِيُّ بْنُ أَبِي طَالِبٍ فَقَالَ لَمْ يُضَيِّقِ اللَّهُ عَلَيْكَ وَالنِّسَاءُ سِوَاهَا كَثِيرٌ وَإِنْ تَسْأَلِ الْجَارِيَةَ تَصْدُقْكَ - قَالَتْ - فَدَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم بَرِيرَةَ فَقَالَ ‏"‏ أَىْ بَرِيرَةُ هَلْ رَأَيْتِ مِنْ شَىْءٍ يَرِيبُكِ مِنْ عَائِشَةَ ‏"‏ ‏.‏ قَالَتْ لَهُ بَرِيرَةُ وَالَّذِي بَعَثَكَ بِالْحَقِّ إِنْ رَأَيْتُ عَلَيْهَا أَمْرًا قَطُّ أَغْمِصُهُ عَلَيْهَا أَكْثَرَ مِنْ أَنَّهَا جَارِيَةٌ حَدِيثَةُ السِّنِّ تَنَامُ عَنْ عَجِينِ أَهْلِهَا فَتَأْتِي الدَّاجِنُ فَتَأْكُلُهُ - قَالَتْ - فَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ فَاسْتَعْذَرَ مِنْ عَبْدِ اللَّهِ بْنِ أُبَىٍّ ابْنِ سَلُولَ - قَالَتْ - فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم وَهُوَ عَلَى الْمِنْبَرِ ‏"‏ يَا مَعْشَرَ الْمُسْلِمِينَ مَنْ يَعْذِرُنِي مِنْ رَجُلٍ قَدْ بَلَغَ أَذَاهُ فِي أَهْلِ بَيْتِي فَوَاللَّهِ مَا عَلِمْتُ عَلَى أَهْلِي إِلاَّ خَيْرًا وَلَقَدْ ذَكَرُوا رَجُلاً مَا عَلِمْتُ عَلَيْهِ إِلاَّ خَيْرًا وَمَا كَانَ يَدْخُلُ عَلَى أَهْلِي إِلاَّ مَعِي ‏"‏ ‏.‏ فَقَامَ سَعْدُ بْنُ مُعَاذٍ الأَنْصَارِيُّ فَقَالَ أَنَا أَعْذِرُكَ مِنْهُ يَا رَسُولَ اللَّهِ إِنْ كَانَ مِنَ الأَوْسِ ضَرَبْنَا عُنُقَهُ وَإِنْ كَانَ مِنْ إِخْوَانِنَا الْخَزْرَجِ أَمَرْتَنَا فَفَعَلْنَا أَمْرَكَ - قَالَتْ - فَقَامَ سَعْدُ بْنُ عُبَادَةَ وَهُوَ سَيِّدُ الْخَزْرَجِ وَكَانَ رَجُلاً صَالِحًا وَلَكِنِ اجْتَهَلَتْهُ الْحَمِيَّةُ فَقَالَ لِسَعْدِ بْنِ مُعَاذٍ كَذَبْتَ لَعَمْرُ اللَّهِ لاَ تَقْتُلُهُ وَلاَ تَقْدِرُ عَلَى قَتْلِهِ ‏.‏ فَقَامَ أُسَيْدُ بْنُ حُضَيْرٍ وَهُوَ ابْنُ عَمِّ سَعْدِ بْنِ مُعَاذٍ فَقَالَ لِسَعْدِ بْنِ عُبَادَةَ كَذَبْتَ لَعَمْرُ اللَّهِ لَنَقْتُلَنَّهُ فَإِنَّكَ مُنَافِقٌ تُجَادِلُ عَنِ الْمُنَافِقِينَ فَثَارَ الْحَيَّانِ الأَوْسُ وَالْخَزْرَجُ حَتَّى هَمُّوا أَنْ يَقْتَتِلُوا وَرَسُولُ اللَّهِ صلى الله عليه وسلم قَائِمٌ عَلَى الْمِنْبَرِ فَلَمْ يَزَلْ رَسُولُ اللَّهِ صلى الله عليه وسلم يُخَفِّضُهُمْ حَتَّى سَكَتُوا وَسَكَتَ - قَالَتْ - وَبَكَيْتُ يَوْمِي ذَلِكَ لاَ يَرْقَأُ لِي دَمْعٌ وَلاَ أَكْتَحِلُ بِنَوْمٍ ثُمَّ بَكَيْتُ لَيْلَتِي الْمُقْبِلَةَ لاَ يَرْقَأُ لِي دَمْعٌ وَلاَ أَكْتَحِلُ بِنَوْمٍ وَأَبَوَاىَ يَظُنَّانِ أَنَّ الْبُكَاءَ فَالِقٌ كَبِدِي فَبَيْنَمَا هُمَا جَالِسَانِ عِنْدِي وَأَنَا أَبْكِي اسْتَأْذَنَتْ عَلَىَّ امْرَأَةٌ مِنَ الأَنْصَارِ فَأَذِنْتُ لَهَا فَجَلَسَتْ تَبْكِي - قَالَتْ - فَبَيْنَا نَحْنُ عَلَى ذَلِكَ دَخَلَ عَلَيْنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فَسَلَّمَ ثُمَّ جَلَسَ - قَالَتْ - وَلَمْ يَجْلِسْ عِنْدِي مُنْذُ قِيلَ لِي مَا قِيلَ وَقَدْ لَبِثَ شَهْرًا لاَ يُوحَى إِلَيْهِ فِي شَأْنِي بِشَىْءٍ - قَالَتْ - فَتَشَهَّدَ رَسُولُ اللَّهِ صلى الله عليه وسلم حِينَ جَلَسَ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ يَا عَائِشَةُ فَإِنَّهُ قَدْ بَلَغَنِي عَنْكِ كَذَا وَكَذَا فَإِنْ كُنْتِ بَرِيئَةً فَسَيُبَرِّئُكِ اللَّهُ وَإِنْ كُنْتِ أَلْمَمْتِ بِذَنْبٍ فَاسْتَغْفِرِي اللَّهَ وَتُوبِي إِلَيْهِ فَإِنَّ الْعَبْدَ إِذَا اعْتَرَفَ بِذَنْبٍ ثُمَّ تَابَ تَابَ اللَّهُ عَلَيْهِ ‏"‏ ‏.‏ قَالَتْ فَلَمَّا قَضَى رَسُولُ اللَّهِ صلى الله عليه وسلم مَقَالَتَهُ قَلَصَ دَمْعِي حَتَّى مَا أُحِسُّ مِنْهُ قَطْرَةً فَقُلْتُ لأَبِي أَجِبْ عَنِّي رَسُولَ اللَّهِ صلى الله عليه وسلم فِيمَا قَالَ ‏.‏ فَقَالَ وَاللَّهِ مَا أَدْرِي مَا أَقُولُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ لأُمِيِّ أَجِيبِي عَنِّي رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَتْ وَاللَّهِ مَا أَدْرِي مَا أَقُولُ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقُلْتُ وَأَنَا جَارِيَةٌ حَدِيثَةُ السِّنِّ لاَ أَقْرَأُ كَثِيرًا مِنَ الْقُرْآنِ إِنِّي وَاللَّهِ لَقَدْ عَرَفْتُ أَنَّكُمْ قَدْ سَمِعْتُمْ بِهَذَا حَتَّى اسْتَقَرَّ فِي نُفُوسِكُمْ وَصَدَّقْتُمْ بِهِ فَإِنْ قُلْتُ لَكُمْ إِنِّي بَرِيئَةٌ وَاللَّهُ يَعْلَمُ أَنِّي بَرِيئَةٌ لاَ تُصَدِّقُونِي بِذَلِكَ وَلَئِنِ اعْتَرَفْتُ لَكُمْ بِأَمْرٍ وَاللَّهُ يَعْلَمُ أَنِّي بَرِيئَةٌ لَتُصَدِّقُونَنِي وَإِنِّي وَاللَّهِ مَا أَجِدُ لِي وَلَكُمْ مَثَلاً إِلاَّ كَمَا قَالَ أَبُو يُوسُفَ فَصَبْرٌ جَمِيلٌ وَاللَّهُ الْمُسْتَعَانُ عَلَى مَا تَصِفُونَ ‏.‏ قَالَتْ ثُمَّ تَحَوَّلْتُ فَاضْطَجَعْتُ عَلَى فِرَاشِي - قَالَتْ - وَأَنَا وَاللَّهِ حِينَئِذٍ أَعْلَمُ أَنِّي بَرِيئَةٌ وَأَنَّ اللَّهَ مُبَرِّئِي بِبَرَاءَتِي وَلَكِنْ وَاللَّهِ مَا كُنْتُ أَظُنُّ أَنْ يُنْزَلَ فِي شَأْنِي وَحْىٌ يُتْلَى وَلَشَأْنِي كَانَ أَحْقَرَ فِي نَفْسِي مِنْ أَنْ يَتَكَلَّمَ اللَّهُ عَزَّ وَجَلَّ فِيَّ بِأَمْرٍ يُتْلَى وَلَكِنِّي كُنْتُ أَرْجُو أَنْ يَرَى رَسُولُ اللَّهِ صلى الله عليه وسلم فِي النَّوْمِ رُؤْيَا يُبَرِّئُنِي اللَّهُ بِهَا قَالَتْ فَوَاللَّهِ مَا رَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم مَجْلِسَهُ وَلاَ خَرَجَ مِنْ أَهْلِ الْبَيْتِ أَحَدٌ حَتَّى أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ عَلَى نَبِيِّهِ صلى الله عليه وسلم فَأَخَذَهُ مَا كَانَ يَأْخُذُهُ مِنَ الْبُرَحَاءِ عِنْدَ الْوَحْىِ حَتَّى إِنَّهُ لَيَتَحَدَّرُ مِنْهُ مِثْلُ الْجُمَانِ مِنَ الْعَرَقِ فِي الْيَوْمِ الشَّاتِ مِنْ ثِقَلِ الْقَوْلِ الَّذِي أُنْزِلَ عَلَيْهِ - قَالَتْ - فَلَمَّا سُرِّيَ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَهُوَ يَضْحَكُ فَكَانَ أَوَّلَ كَلِمَةٍ تَكَلَّمَ بِهَا أَنْ قَالَ ‏"‏ أَبْشِرِي يَا عَائِشَةُ أَمَّا اللَّهُ فَقَدْ بَرَّأَكِ ‏"‏ ‏.‏ فَقَالَتْ لِي أُمِّي قُومِي إِلَيْهِ فَقُلْتُ وَاللَّهِ لاَ أَقُومُ إِلَيْهِ وَلاَ أَحْمَدُ إِلاَّ اللَّهَ هُوَ الَّذِي أَنْزَلَ بَرَاءَتِي - قَالَتْ - فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ إِنَّ الَّذِينَ جَاءُوا بِالإِفْكِ عُصْبَةٌ مِنْكُمْ‏\}‏ عَشْرَ آيَاتٍ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ هَؤُلاَءِ الآيَاتِ بَرَاءَتِي - قَالَتْ - فَقَالَ أَبُو بَكْرٍ وَكَانَ يُنْفِقُ عَلَى مِسْطَحٍ لِقَرَابَتِهِ مِنْهُ وَفَقْرِهِ وَاللَّهِ لاَ أُنْفِقُ عَلَيْهِ شَيْئًا أَبَدًا بَعْدَ الَّذِي قَالَ لِعَائِشَةَ ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَلاَ يَأْتَلِ أُولُو الْفَضْلِ مِنْكُمْ وَالسَّعَةِ أَنْ يُؤْتُوا أُولِي الْقُرْبَى‏\}‏ إِلَى قَوْلِهِ ‏\{‏ أَلاَ تُحِبُّونَ أَنْ يَغْفِرَ اللَّهُ لَكُمْ‏\}‏ قَالَ حِبَّانُ بْنُ مُوسَى قَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ هَذِهِ أَرْجَى آيَةٍ فِي كِتَابِ اللَّهِ ‏.‏ فَقَالَ أَبُو بَكْرٍ وَاللَّهِ إِنِّي لأُحِبُّ أَنْ يَغْفِرَ اللَّهُ لِي ‏.‏ فَرَجَعَ إِلَى مِسْطَحٍ النَّفَقَةَ الَّتِي كَانَ يُنْفِقُ عَلَيْهِ وَقَالَ لاَ أَنْزِعُهَا مِنْهُ أَبَدًا ‏.‏ قَالَتْ عَائِشَةُ وَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم سَأَلَ زَيْنَبَ بِنْتَ جَحْشٍ زَوْجَ النَّبِيِّ صلى الله عليه وسلم عَنْ أَمْرِي ‏"‏ مَا عَلِمْتِ أَوْ مَا رَأَيْتِ ‏"‏ ‏.‏ فَقَالَتْ يَا رَسُولَ اللَّهِ أَحْمِي سَمْعِي وَبَصَرِي وَاللَّهِ مَا عَلِمْتُ إِلاَّ خَيْرًا ‏.‏ قَالَتْ عَائِشَةُ وَهِيَ الَّتِي كَانَتْ تُسَامِينِي مِنْ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم فَعَصَمَهَا اللَّهُ بِالْوَرَعِ وَطَفِقَتْ أُخْتُهَا حَمْنَةُ بِنْتُ جَحْشٍ تُحَارِبُ لَهَا فَهَلَكَتْ فِيمَنْ هَلَكَ ‏.‏ قَالَ الزُّهْرِيُّ فَهَذَا مَا انْتَهَى إِلَيْنَا مِنْ أَمْرِ هَؤُلاَءِ الرَّهْطِ ‏.‏ وَقَالَ فِي حَدِيثِ يُونُسَ احْتَمَلَتْهُ الْحَمِيَّةُ ‏.‏\hadithno{7021}\hadithtrans{Sa'id b. Musayyib, 'Urwa b. Zubair, 'Alqama b. Waqqas and 'Ubaidullah b. Abdullah b. 'Utba b. Mas'ud--all of them reported the story of the false allegation against 'A'isha, the wife of Allah's Apostle (ﷺ). And they (the slanderers) said what they had to say, but Allah exonerated her of this charge and all of them reported a part of the hadith and some of them who had better memories reported more and with better retention, and I tried to retain this hadith (listening) from every one of them that they reported to me and some of them attested the other. (The sumaried substance of the false allegation is this):'A'isha said: Whenever Allah's Messenger (ﷺ) intended to set out on a journey he cast lots amongst his wives and he took one with him in whose favour the lot was cast. It so happened that he cast lots amongst us while setting out on a battle and it was cast in my favour, so I set out along with Allah's Messenger (ﷺ). This relates to the period when the revelation concerning the commands of veil had been made. I was carried in a haudaj and I was brought down where we had to stay. In short, when we set out for return journey from the expedition and our caravan was near Medina, Allah's Messenger (ﷺ) commanded one night to march forward. I also got up when the command for the march was given and moved on until I went out of the encampments of the army and after relieving myself I came to my place. I touched my chest and found that my necklace which had been made of the stones of zafar had been broken. I retraced my steps and tried to search my necklace and this detained me there. The group of people who saddled my ride and placed my haudaj carrying me upon the camels marched on. They were under the impression that I was in it. The women in those days were light of weight and they did not wear much flesh, as they ate less food; so they did not perceive the weight of my haudaj as they placed it upon the camel as I was a young girl at that time. So they drove the camel and Eet out and I found my necklace after the army had marched. I came to my place and there was none to call and none to respond (the call). I waited at my place under the impression that when the people would riot find me they would come back. So I kept sitting at my place. I was overpowered by sleep and slept. Safwan b. Mu'attal Sulami Dhakwini, who had lagged behind the army because of taking rest came to my place walking in the latter part of the night and he saw the body of a person who was asleep. He came to me and recognised me as he had seen rue before it was enjoined to observe purda. I got ap by his voice as he recited Inna lillahi wa inna ilaihi raji'un [we are for Allah and to Him we have to return. ] and I covered my head with my headdress. By Allah, he did not speak to me a word and I did not hear a word from him except Inna lillahi. He made his camel kneel down and I amounted the camel as he pressed tLe camel's foreleg and he moved on leaning the camel by the nose string on which I was riding until we came to the army where it had encamped for rest because of extreme heat. Woe be upon those who harboured doubts about me and the most notorious among them was 'Abdullah b. Ubayy, the great hypocrite. We came to Medina and I fell sick for a month. The people had been deliberating over the statements of those who had brought these calumnies against me. I was absolutely unaware of anything concerning that. This, however, caused doubt in my mind that I did not see Allah's Messenger (may peace be upon him.) treating me with such kindness with which he treated me as I fell ill before this. The Prophet (ﷺ) would coome and greet me with Assalam-o-'Alaikum and only ask me how I was. This caused doubt in my mind, but I was unaware of the evil. I wept outside despite my failing health and there went along with me Umm Mistah and she said the daughter of Abu Rhm b. Muttalib b. 'Abd Manaf and his mother was the daughter of Sakhr b. 'Amir, the sister of the mother of Abu Bakr Sidiq and his son was Mistah b. Uthatha b. 'Abbad b. Muttalib. I and the daughter of Abu Rahm set towards the direction of my house. Something got into the head dress of Umm Mistah and she said: Woe be upon Mistah. And I said. Woe be upon what you say. Do you curse people who had participated in Badr? She said: Innocent woman, have you not heard what he said? I said: What did he say? She conveyed to me the statement of those who had brought false allegations against me. So my illness was aggravated. I went to my house and Allah's Messenger (ﷺ) came to me and he greeted me and then said: How is that woman? I said: Do you permit me to go to the (house) of my parents? She (further) said: I had at that time made up my mind to confirm this news from them. Allah's Messenger (ﷺ) permitted me. So I came to (the house of) my parents and said to my mother: Mother, do you know what the people are talking about? She said: My daughter, you should not worry. By Allah, if there is a handsome woman who is loved by her husband and he has co-wives also they talk many a thing about her. I said: Hallowed be Allah, what are the people talking about? I wept during the whole night until it was morning and I did not have a wink of sleep and I wept even in the morning. As the revelation was delayed (in regard to this matter), so Allah's Messenger (ﷺ) called 'Ali ibn Abi 'Talib and Usama b. Zaid in order to seek their advice in regard to the separation of his wife. Usama b. Zaid told Allah's Messenger (may peace be apen him) about the innocence of his wives and what he knew about his love for them. He said: Allah's Messenger, they are your wives and we know nothing else about them but goodness. And as for 'Ali b. Abu Talib, he said: Allah has not put any unnecessary burden upon you (in regard to your wives). There are a number of women besides her and if you ask that maidservant (Barira) she will tell you the truth. So, Allah's Messenger (ﷺ) called Bailra and said: Barira, did you see anything in 'A'isha which can cause doubt about her? Barira said: By Him Who sent thee with the truth, I have seen nothing objectionable in her but only this much that she is a young girl and she goes to sleep while kneading the flour and the lamb eats that. Thereupon Allah's Messenger (ﷺ) mounted the pulpit and sought vindication against 'Abdullah b. Ubayy b. Salul, and he further said: Who would exonerate me from imputations of that person who has troubled (me) in regard to my family? By Allah, I find nothing in my wife but goodness and the person whom the people have mentioned in this connection is, according to my knowledge, a thoroughly pious person, and he did never get into my house but along with me. Sa'd b. Mu'adh stood up and said: Allah's Messenger, I defend your honour against him. If he belong to the tribe of Aus we would strike his neck and if he belongs to the tribe of our brother Khazraj and you order us we would comply with your order. Then Sa'd b. 'Ubada stood up. He was chief of the Khazraj tribe. He was otherwise a pioas man but he had some what tribal partisanship in him and he said to Sa'd b. Mu'adh: By the everlasting existence of Allah. you are not stating the fact, you will not be able to kill him and you will not have the power to do so. Thereupon, Usaid b. Hudair stood up, and he was the first cousin of Sa'd b. Mu'adh and said to Sa'd b. 'Ubada: By the everlasting existence of Allah, you are not stating the fact. We would kill him. You are a hypocrite and so you argue in defence of the hypocrites, and thus both the tribes Aus and Khazraj were flared up, until they were about to fall upon one another and Allah's Messenger (ﷺ) kept standing upon the pulpit and Allah's Messenger (ﷺ) tried to subside their anger until they became silent and thus there was silence. 'A'isha further reported: I spent the whole day in weeping and even the night and could not have a wink of sleep even next night. My parents thought that this constant weeping of mine would break my heart. I wept and they sat beside me. In the meanwhile a woman of the Ansar came to see me. I permitted her to see me and she also began to weep. And we were in this very state that Allah's Messenger (ﷺ) came and he greeted me and then sat down. He had never sat with me since a month when this rumour was afloat, and there was no revelation (to clarity) my case. Allah's Messenger (ﷺ) recited Tashahhud (there is no god but Allah and Muhammad is His Apostle) and then said: Coming to the point, 'A'isha, this is what has reached me about you and if you are innocent, Allah would Himself vindicate your honour, and if accidentally there has been a lapse on your part seek forgiveness of Allah; He will pardon thee for when a servant makes a confession of his fault and turns (to Him) penitently, Allah also turns to him (mercifully) accepting his repentance. When Allah's Messenger (ﷺ) talked, my tears dried up and not even a single drop of tear was perceived by me (rolling out of my eyes). I said to my father: You give a reply to Allah's Messenger (ﷺ) on my behalf. He said: By Allah, I do not know what I should say to Allah's Messenger (ﷺ). I then said to my mother: Give a reply to Allah's Messenger (ﷺ) on my behalf, but she said: By Allah, I do not know what I should say to Allah's Messenger (ﷺ). I was a small girl at that time and I had not read much of the Qur'an (but I said): By Allah, I perceive that you have heard about this and it has settled down in your mind and you have taken it to be true, so if I say to you that I am quite innocent, and Allah knows that I am innocent, you would never believe me to be true, and if I confess to (the alleged) lapse before you, whereas Allah knows that I am completely innocent (and I have not committed this sin at all), in that case You will take me to be true and, by Allah, I, therefore, find no other alternative for me and for you except that what the father of Yousuf said:, (My course is) comely patience. And Allah it is Whose help is to be sought for in that (predicament) which ye describe" (xii 18). After this I turned my face to the other side and lay down on my bed. By Allah, I was fully aware of this fact that I was innocent but I did not expect that Allah would descend Wahy Matlu (Qur'anic Wahy) in my case as I did not think myself so much important that Allah, the Exalted and Glorious, would speak in this matter in words to be recited. I only hoped that Allah would in vision give an indication of my innocence to Allah's Messenger (ﷺ) during his sleep. And, by Allah, Allah's Messenger (ﷺ) had not moved an inch from where he had been sitting and none from the members of my family had gone that Allah, the Exalted and Glorious, descended revelation upon Allah's Messenger (ﷺ) there and then and he felt the burden which he used to feel at the time of receiving revelation. He began to perspire because of the burden of words of Allah as they descended upon him even during the winter season and there fell the drops of his sweat like silvery beads. When this state of receiving revelation was over, the Messenger of Allah (ﷺ) smiled and the first words which he spoke to me were that he said: 'A'isha, there is glad tidings for you. Verily, Allah has vindicated your honour, and my mother who had been standing by me said: Get up (and thank him, i. e. the Holy Prophet). I said: By Allah, I shall not thank him and laud him but Allah Who has descended revelation vindicating my honour. She ('A'isha) said: Allah, the Exalted and Glorious, revealed:" 'Verily, those who spread the slander are a gang among you" (and) ten (subsequent) verses in regard to my innocence. She further said: Abu Bakr used to give to Mistah (some stipend) as a token of kinship with him and for his poverty and he (Abu Bakr) said: By Allah, now I would not spend anything for him. 'A'isha said: It was upon this that Allah the Exalted and Glorious revealed this verse:" And let not those who possess dignity and ease among you swear to give to the near of the kin" up to" Yearn ye not that Allah may forgive you?" Hibban b. Musa' said that 'Abdullah b. Mubarak used to say: It is a verse contained in the Book which most (eminently) brightens the hope. Abu Bakr said: By Allah, I wish that Allah should pardon me. I shall never stop this stipend. So he continued to give him the stipend which he had withdrawn. 'A'isha said that Allah's Messenger (ﷺ) asked Zainab, daughter of Jahsh, the wife of Allah's Apostle (ﷺ), about me what she knew or what she had seen in me, and she said: Allah's Messenger, I shall not say anything without hearing (with my ears) and seeing with my eyes. By Allah, I find nothing in her but goodness. (And she stated this in spite of the fact) that she was the only lady who amongst the wives of Allah's Apostle (ﷺ) used to vie with me but Allah saved her in bringing false allegation against me because of her God-consciousness. Her sister Hamna bint Jahsh, however, opposed her and she was undone along with others}}
\hadithdefcmd{muslim}{7022}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ الْعَلاَءِ، قَالاَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ هِشَامِ، بْنِ عُرْوَةَ عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ لَمَّا ذُكِرَ مِنْ شَأْنِي الَّذِي ذُكِرَ وَمَا عَلِمْتُ بِهِ قَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم خَطِيبًا فَتَشَهَّدَ فَحَمِدَ اللَّهَ وَأَثْنَى عَلَيْهِ بِمَا هُوَ أَهْلُهُ ثُمَّ قَالَ ‏ "‏ أَمَّا بَعْدُ أَشِيرُوا عَلَىَّ فِي أُنَاسٍ أَبَنُوا أَهْلِي وَايْمُ اللَّهِ مَا عَلِمْتُ عَلَى أَهْلِي مِنْ سُوءٍ قَطُّ وَأَبَنُوهُمْ بِمَنْ وَاللَّهِ مَا عَلِمْتُ عَلَيْهِ مِنْ سُوءٍ قَطُّ وَلاَ دَخَلَ بَيْتِي قَطُّ إِلاَّ وَأَنَا حَاضِرٌ وَلاَ غِبْتُ فِي سَفَرٍ إِلاَّ غَابَ مَعِي ‏"‏ ‏.‏ وَسَاقَ الْحَدِيثَ بِقِصَّتِهِ وَفِيهِ وَلَقَدْ دَخَلَ رَسُولُ اللَّهِ صلى الله عليه وسلم بَيْتِي فَسَأَلَ جَارِيَتِي فَقَالَتْ وَاللَّهِ مَا عَلِمْتُ عَلَيْهَا عَيْبًا إِلاَّ أَنَّهَا كَانَتْ تَرْقُدُ حَتَّى تَدْخُلَ الشَّاةُ فَتَأْكُلَ عَجِينَهَا أَوْ قَالَتْ خَمِيرَهَا - شَكَّ هِشَامٌ - فَانْتَهَرَهَا بَعْضُ أَصْحَابِهِ فَقَالَ اصْدُقِي رَسُولَ اللَّهِ صلى الله عليه وسلم حَتَّى أَسْقَطُوا لَهَا بِهِ فَقَالَتْ سُبْحَانَ اللَّهِ وَاللَّهِ مَا عَلِمْتُ عَلَيْهَا إِلاَّ مَا يَعْلَمُ الصَّائِغُ عَلَى تِبْرِ الذَّهَبِ الأَحْمَرِ ‏.‏ وَقَدْ بَلَغَ الأَمْرُ ذَلِكَ الرَّجُلَ الَّذِي قِيلَ لَهُ فَقَالَ سُبْحَانَ اللَّهِ وَاللَّهِ مَا كَشَفْتُ عَنْ كَنَفِ أُنْثَى قَطُّ ‏.‏ قَالَتْ عَائِشَةُ وَقُتِلَ شَهِيدًا فِي سَبِيلِ اللَّهِ ‏.‏ وَفِيهِ أَيْضًا مِنَ الزِّيَادَةَ وَكَانَ الَّذِينَ تَكَلَّمُوا بِهِ مِسْطَحٌ وَحَمْنَةُ وَحَسَّانُ وَأَمَّا الْمُنَافِقُ عَبْدُ اللَّهِ بْنُ أُبَىٍّ فَهُوَ الَّذِي كَانَ يَسْتَوْشِيهِ وَيَجْمَعُهُ وَهُوَ الَّذِي تَوَلَّى كِبْرَهُ وَحِمْنَةُ ‏.‏\hadithno{7022}\hadithtrans{A'Isha reported:When I came under discussion what the people had to say about me, Allah's Messenger (ﷺ) stood up for delivering an address and he recited tashahhud (I bear witness to the fact that iheie is no god but Allah) and praised Allah, lauded Him what He rightly deserves and then said: Coming to the point. Give me an advice about them who have brought false charge about my family. By Allah, I know no evil in the members of my family and the person in connection with whom the false charge is being levelled, I know no evil in him too. And he never entered my house but in my presence and when I was away on a journey, he remained with me even in that. The rest of the hadith is the same but with this change that Allah's Messenger (ﷺ) came to my house and asked my maidservant and she said: By Allah, I know no fault in her but this that she sleeps, and goat comes and eats the kneaded flour. Some of the Companions (of the Holy Prophet) scolded her and said: State the fact before Allah's Messenger (ﷺ) and they even made a pointed reference (to this incident). She said: gallowed be Allah. By Allah, I know about her as does the jeweller know about the pure piece of gold. And when this news reached the person in connection with whom the allegation was made he said: Hallowed be Allah. By Allah, I have never unveiled any woman. 'A'isha said: He fell as a martyr in the cause of Allah, and there is this addition in this hadith that the people who had brought false allegation amongst them were Mistah and Hamna and Hassan. And so far as the hypocrite 'Abdullah b. Ubayy is concerned, he was one who tried his best to gather the false news and then gave them the wind. And he was in fact a fabricator and there was Hamna, daughter of Jahsh with him}}
\hadithdefcmd{muslim}{7023}{حَدَّثَنِي زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، أَخْبَرَنَا ثَابِتٌ، عَنْ أَنَسٍ، أَنَّ رَجُلاً، كَانَ يُتَّهَمُ بِأُمِّ وَلَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعَلِيٍّ ‏ "‏ اذْهَبْ فَاضْرِبْ عُنُقَهُ ‏"‏ ‏.‏ فَأَتَاهُ عَلِيٌّ فَإِذَا هُوَ فِي رَكِيٍّ يَتَبَرَّدُ فِيهَا فَقَالَ لَهُ عَلِيٌّ اخْرُجْ ‏.‏ فَنَاوَلَهُ يَدَهُ فَأَخْرَجَهُ فَإِذَا هُوَ مَجْبُوبٌ لَيْسَ لَهُ ذَكَرٌ فَكَفَّ عَلِيٌّ عَنْهُ ثُمَّ أَتَى النَّبِيَّ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنَّهُ لَمَجْبُوبٌ مَا لَهُ ذَكَرٌ\hadithno{7023}\hadithtrans{Anas reported that a person was charged with fornication with the slavegirl of Allah's Messenger (ﷺ). Thereupon Allah's Messenger (ﷺ) said to 'Ali:Go and strike his neck. 'Ali came to him and he found him in a well making his body cool. 'Ali said to him: Come out, and as he took hold of his hand and brought him out, he found that his sexual organ had been cut. Hadrat 'Ali refrained from striking his neck. He came to Allah's Apostle (ﷺ) and said: Allah's Messenger, he has not even the sexual organ with him}}
